package androidx.test.core.view;

import android.view.MotionEvent;

public class PointerCoordsBuilder {
    private float orientation;
    private float pressure = 1.0f;
    private float size = 1.0f;
    private float toolMajor;
    private float toolMinor;
    private float touchMajor;
    private float touchMinor;
    private float x = 0.0f;
    private float y = 0.0f;

    private PointerCoordsBuilder() {
    }

    public static PointerCoordsBuilder newBuilder() {
        return new PointerCoordsBuilder();
    }

    public PointerCoordsBuilder setCoords(float x2, float y2) {
        this.x = x2;
        this.y = y2;
        return this;
    }

    public PointerCoordsBuilder setPressure(float pressure2) {
        this.pressure = pressure2;
        return this;
    }

    public PointerCoordsBuilder setSize(float size2) {
        this.size = size2;
        return this;
    }

    public PointerCoordsBuilder setTouch(float touchMajor2, float touchMinor2) {
        this.touchMajor = touchMajor2;
        this.touchMinor = touchMinor2;
        return this;
    }

    public PointerCoordsBuilder setTool(float toolMajor2, float toolMinor2) {
        this.toolMajor = toolMajor2;
        this.toolMinor = toolMinor2;
        return this;
    }

    public PointerCoordsBuilder setOrientation(float orientation2) {
        this.orientation = orientation2;
        return this;
    }

    public MotionEvent.PointerCoords build() {
        MotionEvent.PointerCoords pointerCoords = new MotionEvent.PointerCoords();
        pointerCoords.x = this.x;
        pointerCoords.y = this.y;
        pointerCoords.pressure = this.pressure;
        pointerCoords.size = this.size;
        pointerCoords.touchMajor = this.touchMajor;
        pointerCoords.touchMinor = this.touchMinor;
        pointerCoords.toolMajor = this.toolMajor;
        pointerCoords.toolMinor = this.toolMinor;
        pointerCoords.orientation = this.orientation;
        return pointerCoords;
    }
}
