package androidx.test.internal.platform;

import android.os.StrictMode;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.ServiceLoader;

public final class ServiceLoaderWrapper {

    public interface Factory<T> {
        T create();
    }

    private ServiceLoaderWrapper() {
    }

    public static <T> List<T> loadService(Class<T> serviceClass) {
        StrictMode.ThreadPolicy oldPolicy = StrictMode.allowThreadDiskReads();
        List<T> services = new ArrayList<>();
        Iterator<S> it = ServiceLoader.load(serviceClass).iterator();
        while (it.hasNext()) {
            services.add(it.next());
        }
        StrictMode.setThreadPolicy(oldPolicy);
        return services;
    }

    public static <T> T loadSingleService(Class<T> serviceClass, Factory<T> defaultImplFactory) {
        T impl = loadSingleServiceOrNull(serviceClass);
        if (impl == null) {
            return defaultImplFactory.create();
        }
        return impl;
    }

    public static <T> T loadSingleServiceOrNull(Class<T> serviceClass) {
        List<T> impls = loadService(serviceClass);
        if (impls.isEmpty()) {
            return null;
        }
        if (impls.size() == 1) {
            return impls.get(0);
        }
        String valueOf = String.valueOf(serviceClass.getName());
        throw new IllegalStateException(valueOf.length() != 0 ? "Found more than one implementation for ".concat(valueOf) : new String("Found more than one implementation for "));
    }
}
