package androidx.test.internal.runner;

import android.app.Instrumentation;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.os.Message;
import android.os.Messenger;
import android.os.Parcelable;
import android.os.RemoteException;
import android.util.Log;
import androidx.test.internal.util.Checks;
import androidx.test.internal.util.LogUtil;
import androidx.test.internal.util.ParcelableIBinder;
import androidx.test.platform.app.InstrumentationRegistry;
import androidx.test.runner.MonitoringInstrumentation;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import java.util.UUID;
import java.util.concurrent.Callable;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.FutureTask;

public class InstrumentationConnection {
    public static final String BROADCAST_FILTER = "androidx.test.runner.InstrumentationConnection.event";
    static final String BUNDLE_BR_NEW_BINDER = "new_instrumentation_binder";
    private static final String BUNDLE_KEY_CLIENTS = "instr_clients";
    private static final String BUNDLE_KEY_CLIENT_MESSENGER = "instr_client_msgr";
    private static final String BUNDLE_KEY_CLIENT_TYPE = "instr_client_type";
    private static final String BUNDLE_KEY_UUID = "instr_uuid";
    private static final InstrumentationConnection DEFAULT_INSTANCE = new InstrumentationConnection(InstrumentationRegistry.getInstrumentation().getTargetContext());
    static final int MSG_ADD_CLIENTS_IN_BUNDLE = 6;
    static final int MSG_ADD_INSTRUMENTATION = 4;
    private static final int MSG_HANDLE_INSTRUMENTATION_FROM_BROADCAST = 3;
    private static final int MSG_PERFORM_CLEANUP = 11;
    private static final int MSG_PERFORM_CLEANUP_FINISHED = 12;
    private static final int MSG_REG_CLIENT = 8;
    private static final int MSG_REMOTE_ADD_CLIENT = 0;
    static final int MSG_REMOTE_CLEANUP_REQUEST = 10;
    private static final int MSG_REMOTE_REMOVE_CLIENT = 1;
    private static final int MSG_REMOVE_CLIENTS_IN_BUNDLE = 7;
    private static final int MSG_REMOVE_INSTRUMENTATION = 5;
    private static final int MSG_TERMINATE = 2;
    private static final int MSG_UN_REG_CLIENT = 9;
    private static final String TAG = "InstrConnection";
    /* access modifiers changed from: private */
    public static MonitoringInstrumentation.ActivityFinisher activityFinisher;
    /* access modifiers changed from: private */
    public static Instrumentation instrumentation;
    IncomingHandler incomingHandler;
    final BroadcastReceiver messengerReceiver = new MessengerReceiver();
    private Context targetContext;

    InstrumentationConnection(Context context) {
        this.targetContext = (Context) Checks.checkNotNull(context, "Context can't be null");
    }

    public static InstrumentationConnection getInstance() {
        return DEFAULT_INSTANCE;
    }

    public synchronized void init(Instrumentation instrumentation2, MonitoringInstrumentation.ActivityFinisher finisher) {
        LogUtil.logDebugWithProcess(TAG, "init", new Object[0]);
        if (this.incomingHandler == null) {
            instrumentation = instrumentation2;
            activityFinisher = finisher;
            HandlerThread ht = new HandlerThread("InstrumentationConnectionThread");
            ht.start();
            this.incomingHandler = new IncomingHandler(ht.getLooper());
            Intent intent = new Intent(BROADCAST_FILTER);
            Bundle bundle = new Bundle();
            bundle.putParcelable(BUNDLE_BR_NEW_BINDER, new ParcelableIBinder(this.incomingHandler.messengerHandler.getBinder()));
            intent.putExtra(BUNDLE_BR_NEW_BINDER, bundle);
            try {
                this.targetContext.sendBroadcast(intent);
                this.targetContext.registerReceiver(this.messengerReceiver, new IntentFilter(BROADCAST_FILTER));
            } catch (SecurityException e) {
                Log.i(TAG, "Could not send broadcast or register receiver (isolatedProcess?)");
            }
        }
        return;
    }

    public synchronized void terminate() {
        LogUtil.logDebugWithProcess(TAG, "Terminate is called", new Object[0]);
        IncomingHandler incomingHandler2 = this.incomingHandler;
        if (incomingHandler2 != null) {
            Object unused = incomingHandler2.runSyncTask(new Callable<Void>() {
                public Void call() {
                    InstrumentationConnection.this.incomingHandler.doDie();
                    return null;
                }
            });
            this.targetContext.unregisterReceiver(this.messengerReceiver);
            this.incomingHandler = null;
        }
    }

    /* JADX WARNING: Unknown top exception splitter block from list: {B:27:0x00a4=Splitter:B:27:0x00a4, B:16:0x006f=Splitter:B:16:0x006f} */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public synchronized void requestRemoteInstancesActivityCleanup() {
        /*
            r9 = this;
            monitor-enter(r9)
            androidx.test.internal.runner.InstrumentationConnection$IncomingHandler r0 = r9.incomingHandler     // Catch:{ all -> 0x00aa }
            r1 = 1
            if (r0 == 0) goto L_0x0008
            r0 = 1
            goto L_0x0009
        L_0x0008:
            r0 = 0
        L_0x0009:
            java.lang.String r2 = "Instrumentation Connection in not yet initialized"
            androidx.test.internal.util.Checks.checkState(r0, r2)     // Catch:{ all -> 0x00aa }
            java.util.UUID r0 = java.util.UUID.randomUUID()     // Catch:{ all -> 0x00aa }
            java.util.concurrent.CountDownLatch r2 = new java.util.concurrent.CountDownLatch     // Catch:{ all -> 0x00aa }
            r2.<init>(r1)     // Catch:{ all -> 0x00aa }
            r1 = r2
            androidx.test.internal.runner.InstrumentationConnection$IncomingHandler r2 = r9.incomingHandler     // Catch:{ all -> 0x00aa }
            r2.associateLatch(r0, r1)     // Catch:{ all -> 0x00aa }
            androidx.test.internal.runner.InstrumentationConnection$IncomingHandler r2 = r9.incomingHandler     // Catch:{ all -> 0x00aa }
            r3 = 10
            android.os.Message r2 = r2.obtainMessage(r3)     // Catch:{ all -> 0x00aa }
            androidx.test.internal.runner.InstrumentationConnection$IncomingHandler r3 = r9.incomingHandler     // Catch:{ all -> 0x00aa }
            android.os.Messenger r3 = r3.messengerHandler     // Catch:{ all -> 0x00aa }
            r2.replyTo = r3     // Catch:{ all -> 0x00aa }
            android.os.Bundle r3 = r2.getData()     // Catch:{ all -> 0x00aa }
            java.lang.String r4 = "instr_uuid"
            r3.putSerializable(r4, r0)     // Catch:{ all -> 0x00aa }
            r2.setData(r3)     // Catch:{ all -> 0x00aa }
            androidx.test.internal.runner.InstrumentationConnection$IncomingHandler r4 = r9.incomingHandler     // Catch:{ all -> 0x00aa }
            r4.sendMessage(r2)     // Catch:{ all -> 0x00aa }
            r4 = 2
            java.util.concurrent.TimeUnit r6 = java.util.concurrent.TimeUnit.SECONDS     // Catch:{ InterruptedException -> 0x0077 }
            boolean r4 = r1.await(r4, r6)     // Catch:{ InterruptedException -> 0x0077 }
            if (r4 != 0) goto L_0x006f
            java.lang.String r4 = "InstrConnection"
            java.lang.String r5 = java.lang.String.valueOf(r0)     // Catch:{ InterruptedException -> 0x006d, all -> 0x006b }
            java.lang.String r6 = java.lang.String.valueOf(r5)     // Catch:{ InterruptedException -> 0x006d, all -> 0x006b }
            int r6 = r6.length()     // Catch:{ InterruptedException -> 0x006d, all -> 0x006b }
            int r6 = r6 + 60
            java.lang.StringBuilder r7 = new java.lang.StringBuilder     // Catch:{ InterruptedException -> 0x006d, all -> 0x006b }
            r7.<init>(r6)     // Catch:{ InterruptedException -> 0x006d, all -> 0x006b }
            java.lang.String r6 = "Timed out while attempting to perform activity clean up for "
            r7.append(r6)     // Catch:{ InterruptedException -> 0x006d, all -> 0x006b }
            r7.append(r5)     // Catch:{ InterruptedException -> 0x006d, all -> 0x006b }
            java.lang.String r5 = r7.toString()     // Catch:{ InterruptedException -> 0x006d, all -> 0x006b }
            android.util.Log.w(r4, r5)     // Catch:{ InterruptedException -> 0x006d, all -> 0x006b }
            goto L_0x006f
        L_0x006b:
            r4 = move-exception
            goto L_0x00a4
        L_0x006d:
            r4 = move-exception
            goto L_0x0078
        L_0x006f:
            androidx.test.internal.runner.InstrumentationConnection$IncomingHandler r4 = r9.incomingHandler     // Catch:{ all -> 0x00aa }
            r4.disassociateLatch(r0)     // Catch:{ all -> 0x00aa }
            goto L_0x00a2
        L_0x0075:
            r4 = move-exception
            goto L_0x00a4
        L_0x0077:
            r4 = move-exception
        L_0x0078:
            java.lang.String r5 = "InstrConnection"
            java.lang.String r6 = java.lang.String.valueOf(r0)     // Catch:{ all -> 0x0075 }
            java.lang.String r7 = java.lang.String.valueOf(r6)     // Catch:{ all -> 0x0075 }
            int r7 = r7.length()     // Catch:{ all -> 0x0075 }
            int r7 = r7 + 61
            java.lang.StringBuilder r8 = new java.lang.StringBuilder     // Catch:{ all -> 0x0075 }
            r8.<init>(r7)     // Catch:{ all -> 0x0075 }
            java.lang.String r7 = "Interrupted while waiting for response from message with id: "
            r8.append(r7)     // Catch:{ all -> 0x0075 }
            r8.append(r6)     // Catch:{ all -> 0x0075 }
            java.lang.String r6 = r8.toString()     // Catch:{ all -> 0x0075 }
            android.util.Log.e(r5, r6, r4)     // Catch:{ all -> 0x0075 }
            androidx.test.internal.runner.InstrumentationConnection$IncomingHandler r4 = r9.incomingHandler     // Catch:{ all -> 0x00aa }
            r4.disassociateLatch(r0)     // Catch:{ all -> 0x00aa }
        L_0x00a2:
            monitor-exit(r9)
            return
        L_0x00a4:
            androidx.test.internal.runner.InstrumentationConnection$IncomingHandler r5 = r9.incomingHandler     // Catch:{ all -> 0x00aa }
            r5.disassociateLatch(r0)     // Catch:{ all -> 0x00aa }
            throw r4     // Catch:{ all -> 0x00aa }
        L_0x00aa:
            r0 = move-exception
            monitor-exit(r9)
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: androidx.test.internal.runner.InstrumentationConnection.requestRemoteInstancesActivityCleanup():void");
    }

    public synchronized void registerClient(String type, Messenger messenger) {
        Checks.checkState(this.incomingHandler != null, "Instrumentation Connection in not yet initialized");
        String valueOf = String.valueOf(type);
        Log.i(TAG, valueOf.length() != 0 ? "Register client of type: ".concat(valueOf) : new String("Register client of type: "));
        Bundle bundle = new Bundle();
        bundle.putString(BUNDLE_KEY_CLIENT_TYPE, type);
        bundle.putParcelable(BUNDLE_KEY_CLIENT_MESSENGER, messenger);
        Message msg = this.incomingHandler.obtainMessage(8);
        msg.setData(bundle);
        this.incomingHandler.sendMessage(msg);
    }

    public synchronized Set<Messenger> getClientsForType(String type) {
        return this.incomingHandler.getClientsForType(type);
    }

    public synchronized void unregisterClient(String type, Messenger messenger) {
        Checks.checkState(this.incomingHandler != null, "Instrumentation Connection in not yet initialized");
        String valueOf = String.valueOf(type);
        Log.i(TAG, valueOf.length() != 0 ? "Unregister client of type: ".concat(valueOf) : new String("Unregister client of type: "));
        Bundle bundle = new Bundle();
        bundle.putString(BUNDLE_KEY_CLIENT_TYPE, type);
        bundle.putParcelable(BUNDLE_KEY_CLIENT_MESSENGER, messenger);
        Message msg = this.incomingHandler.obtainMessage(9);
        msg.setData(bundle);
        this.incomingHandler.sendMessage(msg);
    }

    class MessengerReceiver extends BroadcastReceiver {
        MessengerReceiver() {
        }

        public void onReceive(Context context, Intent intent) {
            LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "Broadcast received", new Object[0]);
            Bundle extras = intent.getBundleExtra(InstrumentationConnection.BUNDLE_BR_NEW_BINDER);
            if (extras == null) {
                Log.w(InstrumentationConnection.TAG, "Broadcast intent doesn't contain any extras, ignoring it..");
                return;
            }
            ParcelableIBinder iBinder = (ParcelableIBinder) extras.getParcelable(InstrumentationConnection.BUNDLE_BR_NEW_BINDER);
            if (iBinder != null) {
                Messenger msgr = new Messenger(iBinder.getIBinder());
                Message msg = InstrumentationConnection.this.incomingHandler.obtainMessage(3);
                msg.replyTo = msgr;
                InstrumentationConnection.this.incomingHandler.sendMessage(msg);
            }
        }
    }

    static class IncomingHandler extends Handler {
        /* access modifiers changed from: private */
        public final Map<UUID, CountDownLatch> latches = new HashMap();
        Messenger messengerHandler = new Messenger(this);
        Set<Messenger> otherInstrumentations = new HashSet();
        Map<String, Set<Messenger>> typedClients = new HashMap();

        public IncomingHandler(Looper looper) {
            super(looper);
            if (Looper.getMainLooper() == looper || Looper.myLooper() == looper) {
                throw new IllegalStateException("This handler should not be using the main thread looper nor the instrumentation thread looper.");
            }
        }

        public void handleMessage(Message msg) {
            switch (msg.what) {
                case 0:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_REMOTE_ADD_CLIENT)", new Object[0]);
                    registerClient(msg.getData().getString(InstrumentationConnection.BUNDLE_KEY_CLIENT_TYPE), (Messenger) msg.getData().getParcelable(InstrumentationConnection.BUNDLE_KEY_CLIENT_MESSENGER));
                    return;
                case 1:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_REMOTE_REMOVE_CLIENT)", new Object[0]);
                    unregisterClient(msg.getData().getString(InstrumentationConnection.BUNDLE_KEY_CLIENT_TYPE), msg.replyTo);
                    return;
                case 2:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_TERMINATE)", new Object[0]);
                    doDie();
                    return;
                case 3:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_HANDLE_INSTRUMENTATION_FROM_BROADCAST)", new Object[0]);
                    if (this.otherInstrumentations.add(msg.replyTo)) {
                        sendMessageWithReply(msg.replyTo, 4, (Bundle) null);
                        return;
                    } else {
                        Log.w(InstrumentationConnection.TAG, "Broadcast with existing binder was received, ignoring it..");
                        return;
                    }
                case 4:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_ADD_INSTRUMENTATION)", new Object[0]);
                    if (this.otherInstrumentations.add(msg.replyTo)) {
                        if (!this.typedClients.isEmpty()) {
                            sendMessageWithReply(msg.replyTo, 6, (Bundle) null);
                        }
                        clientsRegistrationFromBundle(msg.getData(), true);
                        return;
                    }
                    Log.w(InstrumentationConnection.TAG, "Message with existing binder was received, ignoring it..");
                    return;
                case 5:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_REMOVE_INSTRUMENTATION)", new Object[0]);
                    if (!this.otherInstrumentations.remove(msg.replyTo)) {
                        Log.w(InstrumentationConnection.TAG, "Attempting to remove a non-existent binder!");
                        return;
                    }
                    return;
                case 6:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_ADD_CLIENTS_IN_BUNDLE)", new Object[0]);
                    clientsRegistrationFromBundle(msg.getData(), true);
                    return;
                case 7:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_REMOVE_CLIENTS_IN_BUNDLE)", new Object[0]);
                    clientsRegistrationFromBundle(msg.getData(), false);
                    return;
                case 8:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_REG_CLIENT)", new Object[0]);
                    registerClient(msg.getData().getString(InstrumentationConnection.BUNDLE_KEY_CLIENT_TYPE), (Messenger) msg.getData().getParcelable(InstrumentationConnection.BUNDLE_KEY_CLIENT_MESSENGER));
                    sendMessageToOtherInstr(0, msg.getData());
                    return;
                case 9:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_UN_REG_CLIENT)", new Object[0]);
                    unregisterClient(msg.getData().getString(InstrumentationConnection.BUNDLE_KEY_CLIENT_TYPE), (Messenger) msg.getData().getParcelable(InstrumentationConnection.BUNDLE_KEY_CLIENT_MESSENGER));
                    sendMessageToOtherInstr(1, msg.getData());
                    return;
                case 10:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_REMOTE_CLEANUP_REQUEST)", new Object[0]);
                    if (this.otherInstrumentations.isEmpty()) {
                        Message m = obtainMessage(12);
                        m.setData(msg.getData());
                        sendMessage(m);
                        return;
                    }
                    sendMessageToOtherInstr(11, msg.getData());
                    return;
                case 11:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_PERFORM_CLEANUP)", new Object[0]);
                    InstrumentationConnection.instrumentation.runOnMainSync(InstrumentationConnection.activityFinisher);
                    sendMessageWithReply(msg.replyTo, 12, msg.getData());
                    return;
                case 12:
                    LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "handleMessage(MSG_PERFORM_CLEANUP_FINISHED)", new Object[0]);
                    notifyLatch((UUID) msg.getData().getSerializable(InstrumentationConnection.BUNDLE_KEY_UUID));
                    return;
                default:
                    int i = msg.what;
                    StringBuilder sb = new StringBuilder(42);
                    sb.append("Unknown message code received: ");
                    sb.append(i);
                    Log.w(InstrumentationConnection.TAG, sb.toString());
                    super.handleMessage(msg);
                    return;
            }
        }

        private void notifyLatch(UUID uuid) {
            if (uuid == null || !this.latches.containsKey(uuid)) {
                String valueOf = String.valueOf(uuid);
                StringBuilder sb = new StringBuilder(String.valueOf(valueOf).length() + 16);
                sb.append("Latch not found ");
                sb.append(valueOf);
                Log.w(InstrumentationConnection.TAG, sb.toString());
                return;
            }
            this.latches.get(uuid).countDown();
        }

        /* access modifiers changed from: private */
        public void associateLatch(final UUID latchId, final CountDownLatch latch) {
            runSyncTask(new Callable<Void>() {
                public Void call() {
                    IncomingHandler.this.latches.put(latchId, latch);
                    return null;
                }
            });
        }

        /* access modifiers changed from: private */
        public void disassociateLatch(final UUID latchId) {
            runSyncTask(new Callable<Void>() {
                public Void call() {
                    IncomingHandler.this.latches.remove(latchId);
                    return null;
                }
            });
        }

        /* access modifiers changed from: private */
        public <T> T runSyncTask(Callable<T> task) {
            FutureTask<T> futureTask = new FutureTask<>(task);
            post(futureTask);
            try {
                return futureTask.get();
            } catch (InterruptedException e) {
                throw new IllegalStateException(e.getCause());
            } catch (ExecutionException e2) {
                throw new IllegalStateException(e2.getCause());
            }
        }

        /* access modifiers changed from: private */
        public void doDie() {
            Log.i(InstrumentationConnection.TAG, "terminating process");
            sendMessageToOtherInstr(5, (Bundle) null);
            this.otherInstrumentations.clear();
            this.typedClients.clear();
            LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "quitting looper...", new Object[0]);
            getLooper().quit();
            LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "finishing instrumentation...", new Object[0]);
            InstrumentationConnection.instrumentation.finish(0, (Bundle) null);
            Instrumentation unused = InstrumentationConnection.instrumentation = null;
            MonitoringInstrumentation.ActivityFinisher unused2 = InstrumentationConnection.activityFinisher = null;
        }

        /* access modifiers changed from: private */
        public Set<Messenger> getClientsForType(final String type) {
            FutureTask<Set<Messenger>> associationTask = new FutureTask<>(new Callable<Set<Messenger>>() {
                public Set<Messenger> call() {
                    return IncomingHandler.this.typedClients.get(type);
                }
            });
            post(associationTask);
            try {
                return associationTask.get();
            } catch (InterruptedException e) {
                throw new IllegalStateException(e);
            } catch (ExecutionException e2) {
                throw new IllegalStateException(e2.getCause());
            }
        }

        private void sendMessageWithReply(Messenger toMessenger, int what, Bundle data) {
            StringBuilder sb = new StringBuilder(45);
            sb.append("sendMessageWithReply type: ");
            sb.append(what);
            sb.append(" called");
            LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, sb.toString(), new Object[0]);
            Message msg = obtainMessage(what);
            msg.replyTo = this.messengerHandler;
            if (data != null) {
                msg.setData(data);
            }
            if (!this.typedClients.isEmpty()) {
                Bundle clientsBundle = msg.getData();
                clientsBundle.putStringArrayList(InstrumentationConnection.BUNDLE_KEY_CLIENTS, new ArrayList<>(this.typedClients.keySet()));
                for (Map.Entry<String, Set<Messenger>> entry : this.typedClients.entrySet()) {
                    clientsBundle.putParcelableArray(String.valueOf(entry.getKey()), (Messenger[]) entry.getValue().toArray(new Messenger[entry.getValue().size()]));
                }
                msg.setData(clientsBundle);
            }
            try {
                toMessenger.send(msg);
            } catch (RemoteException e) {
                Log.w(InstrumentationConnection.TAG, "The remote process is terminated unexpectedly", e);
                instrBinderDied(toMessenger);
            }
        }

        private void sendMessageToOtherInstr(int what, Bundle data) {
            LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "sendMessageToOtherInstr() called with: what = [%s], data = [%s]", Integer.valueOf(what), data);
            for (Messenger otherInstr : this.otherInstrumentations) {
                sendMessageWithReply(otherInstr, what, data);
            }
        }

        private void clientsRegistrationFromBundle(Bundle clientsBundle, boolean shouldRegister) {
            LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "clientsRegistrationFromBundle called", new Object[0]);
            if (clientsBundle == null) {
                Log.w(InstrumentationConnection.TAG, "The client bundle is null, ignoring...");
                return;
            }
            ArrayList<String> clientTypes = clientsBundle.getStringArrayList(InstrumentationConnection.BUNDLE_KEY_CLIENTS);
            if (clientTypes == null) {
                Log.w(InstrumentationConnection.TAG, "No clients found in the given bundle");
                return;
            }
            Iterator<String> it = clientTypes.iterator();
            while (it.hasNext()) {
                String type = it.next();
                Parcelable[] clientArray = clientsBundle.getParcelableArray(String.valueOf(type));
                if (clientArray != null) {
                    for (Parcelable client : clientArray) {
                        if (shouldRegister) {
                            registerClient(type, (Messenger) client);
                        } else {
                            unregisterClient(type, (Messenger) client);
                        }
                    }
                }
            }
        }

        private void registerClient(String type, Messenger client) {
            LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "registerClient called with type = [%s] client = [%s]", type, client);
            Checks.checkNotNull(type, "type cannot be null!");
            Checks.checkNotNull(client, "client cannot be null!");
            Set<Messenger> clientSet = this.typedClients.get(type);
            if (clientSet == null) {
                Set<Messenger> clientSet2 = new HashSet<>();
                clientSet2.add(client);
                this.typedClients.put(type, clientSet2);
                return;
            }
            clientSet.add(client);
        }

        private void unregisterClient(String type, Messenger client) {
            LogUtil.logDebugWithProcess(InstrumentationConnection.TAG, "unregisterClient called with type = [%s] client = [%s]", type, client);
            Checks.checkNotNull(type, "type cannot be null!");
            Checks.checkNotNull(client, "client cannot be null!");
            if (!this.typedClients.containsKey(type)) {
                String valueOf = String.valueOf(type);
                Log.w(InstrumentationConnection.TAG, valueOf.length() != 0 ? "There are no registered clients for type: ".concat(valueOf) : new String("There are no registered clients for type: "));
                return;
            }
            Set<Messenger> clientSet = this.typedClients.get(type);
            if (!clientSet.contains(client)) {
                StringBuilder sb = new StringBuilder(String.valueOf(type).length() + 78);
                sb.append("Could not unregister client for type ");
                sb.append(type);
                sb.append(" because it doesn't seem to be registered");
                Log.w(InstrumentationConnection.TAG, sb.toString());
                return;
            }
            clientSet.remove(client);
            if (clientSet.isEmpty()) {
                this.typedClients.remove(type);
            }
        }

        private void instrBinderDied(Messenger instrMessenger) {
            Message msg = obtainMessage(5);
            msg.replyTo = instrMessenger;
            sendMessage(msg);
        }
    }
}
