package androidx.test.internal.runner.intent;

import android.content.Intent;
import android.util.Log;
import androidx.test.runner.intent.IntentCallback;
import androidx.test.runner.intent.IntentMonitor;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

public final class IntentMonitorImpl implements IntentMonitor {
    private static final String TAG = "IntentMonitorImpl";
    List<WeakReference<IntentCallback>> callbacks = Collections.synchronizedList(new ArrayList());

    public void addIntentCallback(IntentCallback callback) {
        if (callback != null) {
            boolean needsAdd = true;
            Iterator<WeakReference<IntentCallback>> refIter = this.callbacks.iterator();
            while (refIter.hasNext()) {
                IntentCallback storedCallback = (IntentCallback) refIter.next().get();
                if (storedCallback == null) {
                    refIter.remove();
                } else if (storedCallback == callback) {
                    needsAdd = false;
                }
            }
            if (needsAdd) {
                this.callbacks.add(new WeakReference(callback));
                return;
            }
            return;
        }
        throw new NullPointerException("callback cannot be null!");
    }

    public void removeIntentCallback(IntentCallback callback) {
        if (callback != null) {
            Iterator<WeakReference<IntentCallback>> refIter = this.callbacks.iterator();
            while (refIter.hasNext()) {
                IntentCallback storedCallback = (IntentCallback) refIter.next().get();
                if (storedCallback == null) {
                    refIter.remove();
                } else if (storedCallback == callback) {
                    refIter.remove();
                }
            }
            return;
        }
        throw new NullPointerException("callback cannot be null!");
    }

    public void signalIntent(Intent intent) {
        Iterator<WeakReference<IntentCallback>> refIter = this.callbacks.iterator();
        while (refIter.hasNext()) {
            IntentCallback callback = (IntentCallback) refIter.next().get();
            if (callback == null) {
                refIter.remove();
            } else {
                try {
                    callback.onIntentSent(new Intent(intent));
                } catch (RuntimeException e) {
                    Log.e(TAG, String.format("Callback threw exception! (callback: %s intent: %s)", new Object[]{callback, intent}), e);
                }
            }
        }
    }
}
