package androidx.test.runner;

import android.app.Activity;
import android.app.Application;
import android.app.Fragment;
import android.app.Instrumentation;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.IBinder;
import android.os.Looper;
import android.os.MessageQueue;
import android.os.UserHandle;
import android.util.Log;
import androidx.test.internal.platform.app.ActivityLifecycleTimeout;
import androidx.test.internal.runner.InstrumentationConnection;
import androidx.test.internal.runner.hidden.ExposedInstrumentationApi;
import androidx.test.internal.runner.intent.IntentMonitorImpl;
import androidx.test.internal.runner.intercepting.DefaultInterceptingActivityFactory;
import androidx.test.internal.runner.lifecycle.ActivityLifecycleMonitorImpl;
import androidx.test.internal.runner.lifecycle.ApplicationLifecycleMonitorImpl;
import androidx.test.internal.util.Checks;
import androidx.test.internal.util.ProcSummary;
import androidx.test.platform.app.InstrumentationRegistry;
import androidx.test.runner.intent.IntentMonitorRegistry;
import androidx.test.runner.intent.IntentStubberRegistry;
import androidx.test.runner.intercepting.InterceptingActivityFactory;
import androidx.test.runner.lifecycle.ActivityLifecycleMonitor;
import androidx.test.runner.lifecycle.ActivityLifecycleMonitorRegistry;
import androidx.test.runner.lifecycle.ApplicationLifecycleMonitorRegistry;
import androidx.test.runner.lifecycle.ApplicationStage;
import androidx.test.runner.lifecycle.Stage;
import java.lang.Thread;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.EnumSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;
import java.util.concurrent.FutureTask;
import java.util.concurrent.SynchronousQueue;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicLong;

public class MonitoringInstrumentation extends ExposedInstrumentationApi {
    private static final long MILLIS_TO_POLL_FOR_ACTIVITY_STOP;
    private static final long MILLIS_TO_WAIT_FOR_ACTIVITY_TO_STOP;
    private static final String TAG = "MonitoringInstr";
    private AtomicBoolean anActivityHasBeenLaunched = new AtomicBoolean(false);
    private ApplicationLifecycleMonitorImpl applicationMonitor = new ApplicationLifecycleMonitorImpl();
    private ExecutorService executorService;
    private volatile boolean finished = false;
    private Handler handlerForMainLooper;
    private MessageQueue.IdleHandler idleHandler = new MessageQueue.IdleHandler() {
        public boolean queueIdle() {
            MonitoringInstrumentation.this.lastIdleTime.set(System.currentTimeMillis());
            return true;
        }
    };
    private IntentMonitorImpl intentMonitor = new IntentMonitorImpl();
    private volatile InterceptingActivityFactory interceptingActivityFactory;
    private ThreadLocal<Boolean> isDexmakerClassLoaderInitialized = new ThreadLocal<>();
    /* access modifiers changed from: private */
    public AtomicBoolean isJsBridgeLoaded = new AtomicBoolean(false);
    private volatile Boolean isOriginalInstr = null;
    private String jsBridgeClassName;
    /* access modifiers changed from: private */
    public AtomicLong lastIdleTime = new AtomicLong(0);
    /* access modifiers changed from: private */
    public ActivityLifecycleMonitorImpl lifecycleMonitor = new ActivityLifecycleMonitorImpl();
    /* access modifiers changed from: private */
    public Thread.UncaughtExceptionHandler standardHandler;
    private AtomicInteger startedActivityCounter = new AtomicInteger(0);

    static {
        long millis = TimeUnit.SECONDS.toMillis(2);
        MILLIS_TO_WAIT_FOR_ACTIVITY_TO_STOP = millis;
        MILLIS_TO_POLL_FOR_ACTIVITY_STOP = millis / 40;
    }

    public void onCreate(Bundle arguments) {
        Log.i(TAG, "Instrumentation started!");
        logUncaughtExceptions();
        installMultidex();
        InstrumentationRegistry.registerInstance(this, arguments);
        androidx.test.InstrumentationRegistry.registerInstance(this, arguments);
        ActivityLifecycleMonitorRegistry.registerInstance(this.lifecycleMonitor);
        ApplicationLifecycleMonitorRegistry.registerInstance(this.applicationMonitor);
        IntentMonitorRegistry.registerInstance(this.intentMonitor);
        this.handlerForMainLooper = new Handler(Looper.getMainLooper());
        this.executorService = new ThreadPoolExecutor(0, Integer.MAX_VALUE, 0, TimeUnit.SECONDS, new SynchronousQueue(), new ThreadFactory(this) {
            public Thread newThread(Runnable runnable) {
                Thread thread = Executors.defaultThreadFactory().newThread(runnable);
                thread.setName(MonitoringInstrumentation.class.getSimpleName());
                return thread;
            }
        });
        Looper.myQueue().addIdleHandler(this.idleHandler);
        super.onCreate(arguments);
        specifyDexMakerCacheProperty();
        setupDexmakerClassloader();
        useDefaultInterceptingActivityFactory();
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0040, code lost:
        r1 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0046, code lost:
        throw new java.lang.RuntimeException("multidex is available at runtime, but calling it failed.", r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0047, code lost:
        r1 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x004d, code lost:
        throw new java.lang.RuntimeException("multidex is available at runtime, but calling it failed.", r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x004e, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x004f, code lost:
        android.util.Log.i(TAG, "No multidex.", r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0054, code lost:
        android.util.Log.i(TAG, "No multidex.");
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:?, code lost:
        return;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:11:0x0040 A[ExcHandler: IllegalAccessException (r1v2 'iae' java.lang.IllegalAccessException A[CUSTOM_DECLARE]), Splitter:B:2:0x000c] */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x0047 A[ExcHandler: InvocationTargetException (r1v1 'ite' java.lang.reflect.InvocationTargetException A[CUSTOM_DECLARE]), Splitter:B:2:0x000c] */
    /* JADX WARNING: Removed duplicated region for block: B:19:0x0053 A[ExcHandler: ClassNotFoundException (e java.lang.ClassNotFoundException), Splitter:B:2:0x000c] */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public void installMultidex() {
        /*
            r10 = this;
            java.lang.String r0 = "multidex is available at runtime, but calling it failed."
            java.lang.String r1 = "No multidex."
            java.lang.String r2 = "MonitoringInstr"
            int r3 = android.os.Build.VERSION.SDK_INT
            r4 = 21
            if (r3 >= r4) goto L_0x0057
            java.lang.Class r3 = getMultiDexClass()     // Catch:{ ClassNotFoundException -> 0x0053, NoSuchMethodException -> 0x004e, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            java.lang.String r4 = "installInstrumentation"
            r5 = 2
            java.lang.Class[] r6 = new java.lang.Class[r5]     // Catch:{ NoSuchMethodException -> 0x0036, ClassNotFoundException -> 0x0053, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            java.lang.Class<android.content.Context> r7 = android.content.Context.class
            r8 = 0
            r6[r8] = r7     // Catch:{ NoSuchMethodException -> 0x0036, ClassNotFoundException -> 0x0053, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            java.lang.Class<android.content.Context> r7 = android.content.Context.class
            r9 = 1
            r6[r9] = r7     // Catch:{ NoSuchMethodException -> 0x0036, ClassNotFoundException -> 0x0053, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            java.lang.reflect.Method r4 = r3.getDeclaredMethod(r4, r6)     // Catch:{ NoSuchMethodException -> 0x0036, ClassNotFoundException -> 0x0053, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            r6 = 0
            java.lang.Object[] r5 = new java.lang.Object[r5]     // Catch:{ NoSuchMethodException -> 0x0036, ClassNotFoundException -> 0x0053, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            android.content.Context r7 = r10.getContext()     // Catch:{ NoSuchMethodException -> 0x0036, ClassNotFoundException -> 0x0053, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            r5[r8] = r7     // Catch:{ NoSuchMethodException -> 0x0036, ClassNotFoundException -> 0x0053, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            android.content.Context r7 = r10.getTargetContext()     // Catch:{ NoSuchMethodException -> 0x0036, ClassNotFoundException -> 0x0053, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            r5[r9] = r7     // Catch:{ NoSuchMethodException -> 0x0036, ClassNotFoundException -> 0x0053, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            r4.invoke(r6, r5)     // Catch:{ NoSuchMethodException -> 0x0036, ClassNotFoundException -> 0x0053, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            goto L_0x0057
        L_0x0036:
            r4 = move-exception
            java.lang.String r5 = "Could not find MultiDex.installInstrumentation. Calling MultiDex.install instead. Is an old version of the multidex library being used? If test app is using multidex, classes might not be found"
            android.util.Log.w(r2, r5)     // Catch:{ ClassNotFoundException -> 0x0053, NoSuchMethodException -> 0x004e, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            r10.installOldMultiDex(r3)     // Catch:{ ClassNotFoundException -> 0x0053, NoSuchMethodException -> 0x004e, InvocationTargetException -> 0x0047, IllegalAccessException -> 0x0040 }
            goto L_0x0057
        L_0x0040:
            r1 = move-exception
            java.lang.RuntimeException r2 = new java.lang.RuntimeException
            r2.<init>(r0, r1)
            throw r2
        L_0x0047:
            r1 = move-exception
            java.lang.RuntimeException r2 = new java.lang.RuntimeException
            r2.<init>(r0, r1)
            throw r2
        L_0x004e:
            r0 = move-exception
            android.util.Log.i(r2, r1, r0)
            goto L_0x0057
        L_0x0053:
            r0 = move-exception
            android.util.Log.i(r2, r1)
        L_0x0057:
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: androidx.test.runner.MonitoringInstrumentation.installMultidex():void");
    }

    private static Class<?> getMultiDexClass() throws ClassNotFoundException {
        try {
            return Class.forName("androidx.multidex.MultiDex");
        } catch (ClassNotFoundException e) {
            return Class.forName("androidx.multidex.MultiDex");
        }
    }

    /* access modifiers changed from: protected */
    public void installOldMultiDex(Class<?> multidexClass) throws NoSuchMethodException, InvocationTargetException, IllegalAccessException {
        multidexClass.getDeclaredMethod("install", new Class[]{Context.class}).invoke((Object) null, new Object[]{getTargetContext()});
    }

    /* access modifiers changed from: protected */
    public void specifyDexMakerCacheProperty() {
        System.getProperties().put("dexmaker.dexcache", getTargetContext().getDir("dxmaker_cache", 0).getAbsolutePath());
    }

    /* access modifiers changed from: protected */
    public final void setJsBridgeClassName(String className) {
        if (className == null) {
            throw new NullPointerException("JsBridge class name cannot be null!");
        } else if (!this.isJsBridgeLoaded.get()) {
            this.jsBridgeClassName = className;
        } else {
            throw new IllegalStateException("JsBridge is already loaded!");
        }
    }

    private void setupDexmakerClassloader() {
        if (!Boolean.TRUE.equals(this.isDexmakerClassLoaderInitialized.get())) {
            ClassLoader originalClassLoader = Thread.currentThread().getContextClassLoader();
            ClassLoader newClassLoader = getTargetContext().getClassLoader();
            if (originalClassLoader != newClassLoader) {
                Log.i(TAG, String.format("Setting context classloader to '%s', Original: '%s'", new Object[]{newClassLoader, originalClassLoader}));
                Thread.currentThread().setContextClassLoader(newClassLoader);
            }
            this.isDexmakerClassLoaderInitialized.set(Boolean.TRUE);
        }
    }

    private void logUncaughtExceptions() {
        this.standardHandler = Thread.currentThread().getUncaughtExceptionHandler();
        Thread.currentThread().setUncaughtExceptionHandler(new Thread.UncaughtExceptionHandler() {
            public void uncaughtException(Thread t, Throwable e) {
                MonitoringInstrumentation.this.onException(t, e);
                if (MonitoringInstrumentation.this.standardHandler != null) {
                    Log.w(MonitoringInstrumentation.TAG, String.format("Invoking uncaught exception handler %s (a %s)", new Object[]{MonitoringInstrumentation.this.standardHandler, MonitoringInstrumentation.this.standardHandler.getClass()}));
                    MonitoringInstrumentation.this.standardHandler.uncaughtException(t, e);
                } else {
                    String valueOf = String.valueOf(t.getName());
                    Log.w(MonitoringInstrumentation.TAG, valueOf.length() != 0 ? "Invoking uncaught exception handler for thread: ".concat(valueOf) : new String("Invoking uncaught exception handler for thread: "));
                    t.getThreadGroup().uncaughtException(t, e);
                }
                if (!"robolectric".equals(Build.FINGERPRINT) && Looper.getMainLooper().getThread().equals(t)) {
                    Log.e(MonitoringInstrumentation.TAG, "The main thread has died and the handlers didn't care, exiting");
                    System.exit(-10);
                }
            }
        });
    }

    /* access modifiers changed from: protected */
    public void restoreUncaughtExceptionHandler() {
        Thread.currentThread().setUncaughtExceptionHandler(this.standardHandler);
    }

    public void onStart() {
        super.onStart();
        String str = this.jsBridgeClassName;
        if (str != null) {
            tryLoadingJsBridge(str);
        }
        waitForIdleSync();
        setupDexmakerClassloader();
        InstrumentationConnection.getInstance().init(this, new ActivityFinisher());
    }

    public void finish(int resultCode, Bundle results) {
        if (this.finished) {
            Log.w(TAG, "finish called 2x!");
            return;
        }
        this.finished = true;
        if (shouldWaitForActivitiesToComplete()) {
            this.handlerForMainLooper.post(new ActivityFinisher());
            long startTime = System.currentTimeMillis();
            waitForActivitiesToComplete();
            Log.i(TAG, String.format("waitForActivitiesToComplete() took: %sms", new Object[]{Long.valueOf(System.currentTimeMillis() - startTime)}));
        }
        ActivityLifecycleMonitorRegistry.registerInstance((ActivityLifecycleMonitor) null);
        restoreUncaughtExceptionHandler();
        super.finish(resultCode, results);
    }

    /* access modifiers changed from: protected */
    public boolean shouldWaitForActivitiesToComplete() {
        return Boolean.parseBoolean(InstrumentationRegistry.getArguments().getString("waitForActivitiesToComplete", "true"));
    }

    /* access modifiers changed from: protected */
    public void waitForActivitiesToComplete() {
        if (Looper.getMainLooper() != Looper.myLooper()) {
            long endTime = System.currentTimeMillis() + MILLIS_TO_WAIT_FOR_ACTIVITY_TO_STOP;
            int currentActivityCount = this.startedActivityCounter.get();
            while (currentActivityCount > 0 && System.currentTimeMillis() < endTime) {
                try {
                    StringBuilder sb = new StringBuilder(37);
                    sb.append("Unstopped activity count: ");
                    sb.append(currentActivityCount);
                    Log.i(TAG, sb.toString());
                    Thread.sleep(MILLIS_TO_POLL_FOR_ACTIVITY_STOP);
                    currentActivityCount = this.startedActivityCounter.get();
                } catch (InterruptedException ie) {
                    Log.i(TAG, "Abandoning activity wait due to interruption.", ie);
                }
            }
            if (currentActivityCount > 0) {
                dumpThreadStateToOutputs("ThreadState-unstopped.txt");
                Log.w(TAG, String.format("Still %s activities active after waiting %s ms.", new Object[]{Integer.valueOf(currentActivityCount), Long.valueOf(MILLIS_TO_WAIT_FOR_ACTIVITY_TO_STOP)}));
                return;
            }
            return;
        }
        throw new IllegalStateException("Cannot be called from main thread!");
    }

    public void onDestroy() {
        Log.i(TAG, "Instrumentation Finished!");
        Looper.myQueue().removeIdleHandler(this.idleHandler);
        InstrumentationConnection.getInstance().terminate();
        super.onDestroy();
    }

    public void callApplicationOnCreate(Application app) {
        this.applicationMonitor.signalLifecycleChange(app, ApplicationStage.PRE_ON_CREATE);
        super.callApplicationOnCreate(app);
        this.applicationMonitor.signalLifecycleChange(app, ApplicationStage.CREATED);
    }

    public void runOnMainSync(Runnable runnable) {
        FutureTask<Void> wrapped = new FutureTask<>(runnable, (Object) null);
        super.runOnMainSync(wrapped);
        try {
            wrapped.get();
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        } catch (ExecutionException e2) {
            Throwable cause = e2.getCause();
            if (cause instanceof RuntimeException) {
                throw ((RuntimeException) cause);
            } else if (cause instanceof Error) {
                throw ((Error) cause);
            } else {
                throw new RuntimeException(cause);
            }
        }
    }

    public Activity startActivitySync(final Intent intent) {
        Checks.checkNotMainThread();
        long lastIdleTimeBeforeLaunch = this.lastIdleTime.get();
        if (this.anActivityHasBeenLaunched.compareAndSet(false, true)) {
            intent.addFlags(67108864);
        }
        Future<Activity> startedActivity = this.executorService.submit(new Callable<Activity>() {
            public Activity call() {
                return MonitoringInstrumentation.super.startActivitySync(intent);
            }
        });
        try {
            return startedActivity.get(ActivityLifecycleTimeout.getMillis(), TimeUnit.MILLISECONDS);
        } catch (TimeoutException e) {
            dumpThreadStateToOutputs("ThreadState-startActivityTimeout.txt");
            startedActivity.cancel(true);
            throw new RuntimeException(String.format("Could not launch intent %s within %s milliseconds. Perhaps the main thread has not gone idle within a reasonable amount of time? There could be an animation or something constantly repainting the screen. Or the activity is doing network calls on creation? See the threaddump logs. For your reference the last time the event queue was idle before your activity launch request was %s and now the last time the queue went idle was: %s. If these numbers are the same your activity might be hogging the event queue.", new Object[]{intent, Long.valueOf(ActivityLifecycleTimeout.getMillis()), Long.valueOf(lastIdleTimeBeforeLaunch), Long.valueOf(this.lastIdleTime.get())}));
        } catch (ExecutionException ee) {
            throw new RuntimeException("Could not launch activity", ee.getCause());
        } catch (InterruptedException ie) {
            Thread.currentThread().interrupt();
            throw new RuntimeException("interrupted", ie);
        }
    }

    public Instrumentation.ActivityResult execStartActivity(Context who, IBinder contextThread, IBinder token, Activity target, Intent intent, int requestCode) {
        this.intentMonitor.signalIntent(intent);
        Instrumentation.ActivityResult ar = stubResultFor(intent);
        if (ar == null) {
            return super.execStartActivity(who, contextThread, token, target, intent, requestCode);
        }
        Log.i(TAG, String.format("Stubbing intent %s", new Object[]{intent}));
        return ar;
    }

    public Instrumentation.ActivityResult execStartActivity(Context who, IBinder contextThread, IBinder token, Activity target, Intent intent, int requestCode, Bundle options) {
        this.intentMonitor.signalIntent(intent);
        Instrumentation.ActivityResult ar = stubResultFor(intent);
        if (ar == null) {
            return super.execStartActivity(who, contextThread, token, target, intent, requestCode, options);
        }
        Log.i(TAG, String.format("Stubbing intent %s", new Object[]{intent}));
        return ar;
    }

    public Instrumentation.ActivityResult execStartActivity(Context who, IBinder contextThread, IBinder token, String target, Intent intent, int requestCode, Bundle options) {
        this.intentMonitor.signalIntent(intent);
        Instrumentation.ActivityResult ar = stubResultFor(intent);
        if (ar == null) {
            return super.execStartActivity(who, contextThread, token, target, intent, requestCode, options);
        }
        Log.i(TAG, String.format("Stubbing intent %s", new Object[]{intent}));
        return ar;
    }

    public Instrumentation.ActivityResult execStartActivity(Context who, IBinder contextThread, IBinder token, Activity target, Intent intent, int requestCode, Bundle options, UserHandle user) {
        return super.execStartActivity(who, contextThread, token, target, intent, requestCode, options, user);
    }

    public void execStartActivities(Context who, IBinder contextThread, IBinder token, Activity target, Intent[] intents, Bundle options) {
        Log.d(TAG, "execStartActivities(context, ibinder, ibinder, activity, intent[], bundle)");
        for (Intent intent : intents) {
            execStartActivity(who, contextThread, token, target, intent, -1, options);
        }
    }

    public Instrumentation.ActivityResult execStartActivity(Context who, IBinder contextThread, IBinder token, Fragment target, Intent intent, int requestCode, Bundle options) {
        Log.d(TAG, "execStartActivity(context, IBinder, IBinder, Fragment, Intent, int, Bundle)");
        this.intentMonitor.signalIntent(intent);
        Instrumentation.ActivityResult ar = stubResultFor(intent);
        if (ar == null) {
            return super.execStartActivity(who, contextThread, token, target, intent, requestCode, options);
        }
        Log.i(TAG, String.format("Stubbing intent %s", new Object[]{intent}));
        return ar;
    }

    private static class StubResultCallable implements Callable<Instrumentation.ActivityResult> {
        private final Intent intent;

        StubResultCallable(Intent intent2) {
            this.intent = intent2;
        }

        public Instrumentation.ActivityResult call() {
            return IntentStubberRegistry.getInstance().getActivityResultForIntent(this.intent);
        }
    }

    private Instrumentation.ActivityResult stubResultFor(Intent intent) {
        if (!IntentStubberRegistry.isLoaded()) {
            return null;
        }
        if (Looper.myLooper() == Looper.getMainLooper()) {
            return IntentStubberRegistry.getInstance().getActivityResultForIntent(intent);
        }
        FutureTask<Instrumentation.ActivityResult> task = new FutureTask<>(new StubResultCallable(intent));
        runOnMainSync(task);
        try {
            return task.get();
        } catch (ExecutionException e) {
            throw new RuntimeException(String.format("Could not retrieve stub result for intent %s", new Object[]{intent}), e);
        } catch (InterruptedException e2) {
            Thread.currentThread().interrupt();
            throw new RuntimeException(e2);
        }
    }

    public boolean onException(Object obj, Throwable e) {
        Log.e(TAG, String.format("Exception encountered by: %s. Dumping thread state to outputs and pining for the fjords.", new Object[]{obj}), e);
        dumpThreadStateToOutputs("ThreadState-onException.txt");
        Log.e(TAG, "Dying now...");
        return super.onException(obj, e);
    }

    /* access modifiers changed from: protected */
    public void dumpThreadStateToOutputs(String outputFileName) {
        Log.e("THREAD_STATE", getThreadState());
    }

    /* access modifiers changed from: protected */
    public String getThreadState() {
        Set<Map.Entry<Thread, StackTraceElement[]>> threads = Thread.getAllStackTraces().entrySet();
        StringBuilder threadState = new StringBuilder();
        for (Map.Entry<Thread, StackTraceElement[]> threadAndStack : threads) {
            StringBuilder threadMessage = new StringBuilder("  ").append(threadAndStack.getKey());
            threadMessage.append("\n");
            for (StackTraceElement ste : threadAndStack.getValue()) {
                threadMessage.append("    ");
                threadMessage.append(ste.toString());
                threadMessage.append("\n");
            }
            threadMessage.append("\n");
            threadState.append(threadMessage.toString());
        }
        return threadState.toString();
    }

    public void callActivityOnDestroy(Activity activity) {
        super.callActivityOnDestroy(activity);
        this.lifecycleMonitor.signalLifecycleChange(Stage.DESTROYED, activity);
    }

    public void callActivityOnRestart(Activity activity) {
        super.callActivityOnRestart(activity);
        this.lifecycleMonitor.signalLifecycleChange(Stage.RESTARTED, activity);
    }

    public void callActivityOnCreate(Activity activity, Bundle bundle) {
        this.lifecycleMonitor.signalLifecycleChange(Stage.PRE_ON_CREATE, activity);
        super.callActivityOnCreate(activity, bundle);
        this.lifecycleMonitor.signalLifecycleChange(Stage.CREATED, activity);
    }

    public void callActivityOnStart(Activity activity) {
        this.startedActivityCounter.incrementAndGet();
        try {
            super.callActivityOnStart(activity);
            this.lifecycleMonitor.signalLifecycleChange(Stage.STARTED, activity);
        } catch (RuntimeException re) {
            this.startedActivityCounter.decrementAndGet();
            throw re;
        }
    }

    public void callActivityOnStop(Activity activity) {
        try {
            super.callActivityOnStop(activity);
            this.lifecycleMonitor.signalLifecycleChange(Stage.STOPPED, activity);
        } finally {
            this.startedActivityCounter.decrementAndGet();
        }
    }

    public void callActivityOnResume(Activity activity) {
        super.callActivityOnResume(activity);
        this.lifecycleMonitor.signalLifecycleChange(Stage.RESUMED, activity);
    }

    public void callActivityOnPause(Activity activity) {
        super.callActivityOnPause(activity);
        this.lifecycleMonitor.signalLifecycleChange(Stage.PAUSED, activity);
    }

    public Activity newActivity(Class<?> clazz, Context context, IBinder token, Application application, Intent intent, ActivityInfo info, CharSequence title, Activity parent, String id, Object lastNonConfigurationInstance) throws InstantiationException, IllegalAccessException {
        String activityClassPackageName = clazz.getPackage().getName();
        String contextPackageName = context.getPackageName();
        ComponentName intentComponentName = intent.getComponent();
        if (!contextPackageName.equals(intentComponentName.getPackageName()) && activityClassPackageName.equals(intentComponentName.getPackageName())) {
            intent.setComponent(new ComponentName(contextPackageName, intentComponentName.getClassName()));
        }
        return super.newActivity(clazz, context, token, application, intent, info, title, parent, id, lastNonConfigurationInstance);
    }

    public Activity newActivity(ClassLoader cl, String className, Intent intent) throws InstantiationException, IllegalAccessException, ClassNotFoundException {
        if (this.interceptingActivityFactory.shouldIntercept(cl, className, intent)) {
            return this.interceptingActivityFactory.create(cl, className, intent);
        }
        return super.newActivity(cl, className, intent);
    }

    public void interceptActivityUsing(InterceptingActivityFactory interceptingActivityFactory2) {
        Checks.checkNotNull(interceptingActivityFactory2);
        this.interceptingActivityFactory = interceptingActivityFactory2;
    }

    public void useDefaultInterceptingActivityFactory() {
        this.interceptingActivityFactory = new DefaultInterceptingActivityFactory();
    }

    private void tryLoadingJsBridge(final String className) {
        if (className != null) {
            runOnMainSync(new Runnable() {
                public void run() {
                    try {
                        Class.forName(className).getDeclaredMethod("installBridge", new Class[0]).invoke((Object) null, new Object[0]);
                        MonitoringInstrumentation.this.isJsBridgeLoaded.set(true);
                    } catch (ClassNotFoundException | NoSuchMethodException e) {
                        Log.i(MonitoringInstrumentation.TAG, "No JSBridge.");
                    } catch (IllegalAccessException | InvocationTargetException ite) {
                        throw new RuntimeException("JSbridge is available at runtime, but calling it failed.", ite);
                    }
                }
            });
            return;
        }
        throw new NullPointerException("JsBridge class name cannot be null!");
    }

    public class ActivityFinisher implements Runnable {
        public ActivityFinisher() {
        }

        public void run() {
            List<Activity> activities = new ArrayList<>();
            Iterator it = EnumSet.range(Stage.CREATED, Stage.STOPPED).iterator();
            while (it.hasNext()) {
                activities.addAll(MonitoringInstrumentation.this.lifecycleMonitor.getActivitiesInStage((Stage) it.next()));
            }
            if (activities.size() > 0) {
                int size = activities.size();
                StringBuilder sb = new StringBuilder(60);
                sb.append("Activities that are still in CREATED to STOPPED: ");
                sb.append(size);
                Log.i(MonitoringInstrumentation.TAG, sb.toString());
            }
            for (Activity activity : activities) {
                if (!activity.isFinishing()) {
                    try {
                        String valueOf = String.valueOf(activity);
                        StringBuilder sb2 = new StringBuilder(String.valueOf(valueOf).length() + 20);
                        sb2.append("Finishing activity: ");
                        sb2.append(valueOf);
                        Log.i(MonitoringInstrumentation.TAG, sb2.toString());
                        activity.finish();
                    } catch (RuntimeException e) {
                        Log.e(MonitoringInstrumentation.TAG, "Failed to finish activity.", e);
                    }
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    @Deprecated
    public boolean isPrimaryInstrProcess(String argsProcessName) {
        return isPrimaryInstrProcess();
    }

    /* access modifiers changed from: protected */
    public final boolean isPrimaryInstrProcess() {
        return isOriginalInstrumentationProcess();
    }

    private boolean isHostingProcess(String wantName, ProcSummary ps) {
        int wantLen = wantName.length();
        int cmdLen = ps.cmdline.length();
        if (wantLen == cmdLen) {
            return wantName.equals(ps.cmdline);
        }
        if (wantLen < cmdLen || !wantName.startsWith(ps.cmdline) || !wantName.endsWith(ps.name)) {
            return false;
        }
        String valueOf = String.valueOf(ps);
        StringBuilder sb = new StringBuilder(String.valueOf(valueOf).length() + 165 + String.valueOf(wantName).length());
        sb.append("Use smaller processNames in AndroidManifest.xml. Long names are truncated. This process's cmdline is a prefix of the processName and suffix of comm - assuming: ");
        sb.append(valueOf);
        sb.append(" is: ");
        sb.append(wantName);
        Log.w(TAG, sb.toString());
        return true;
    }

    private boolean isOriginalInstrumentationProcess() {
        Boolean isOriginal = this.isOriginalInstr;
        if (isOriginal == null) {
            isOriginal = Boolean.valueOf(isOriginalUncached());
            this.isOriginalInstr = isOriginal;
        }
        return isOriginal.booleanValue();
    }

    private List<String> getTargetProcessValues() {
        if (Build.VERSION.SDK_INT < 26) {
            return Collections.emptyList();
        }
        try {
            String tpVal = getContext().getPackageManager().getInstrumentationInfo(getComponentName(), 0).targetProcesses;
            if (tpVal == null) {
                tpVal = "";
            }
            String tpVal2 = tpVal.trim();
            if (tpVal2.length() == 0) {
                return Collections.emptyList();
            }
            List<String> tps = new ArrayList<>();
            for (String tp : tpVal2.split(",", -1)) {
                String tp2 = tp.trim();
                if (tp2.length() > 0) {
                    tps.add(tp2);
                }
            }
            return tps;
        } catch (PackageManager.NameNotFoundException unpossible) {
            String valueOf = String.valueOf(getComponentName());
            StringBuilder sb = new StringBuilder(String.valueOf(valueOf).length() + 25);
            sb.append("Cannot locate ourselves: ");
            sb.append(valueOf);
            Log.wtf(TAG, sb.toString(), unpossible);
            String valueOf2 = String.valueOf(getComponentName());
            StringBuilder sb2 = new StringBuilder(String.valueOf(valueOf2).length() + 25);
            sb2.append("Cannot locate ourselves: ");
            sb2.append(valueOf2);
            throw new IllegalStateException(sb2.toString(), unpossible);
        }
    }

    private boolean isOriginalUncached() {
        if (Build.VERSION.SDK_INT < 26) {
            return true;
        }
        List<String> targetProcesses = getTargetProcessValues();
        if (targetProcesses.isEmpty()) {
            return true;
        }
        boolean isWildcard = "*".equals(targetProcesses.get(0));
        if (targetProcesses.size() == 1 && !isWildcard) {
            return true;
        }
        try {
            ProcSummary me = ProcSummary.summarize("self");
            if (!isWildcard) {
                return isHostingProcess(targetProcesses.get(0), me);
            }
            String appDefProcessName = getTargetContext().getApplicationInfo().processName;
            if (appDefProcessName == null) {
                appDefProcessName = getTargetContext().getPackageName();
            }
            return isHostingProcess(appDefProcessName, me);
        } catch (ProcSummary.SummaryException se) {
            Log.w(TAG, "Could not list apps for this user, running in sandbox? Assuming primary", se);
            return false;
        }
    }
}
