package kotlinx.coroutines.flow;

import kotlin.Metadata;
import kotlin.coroutines.CoroutineContext;
import kotlin.jvm.functions.Function1;
import kotlinx.coroutines.DebugKt;
import kotlinx.coroutines.channels.BufferOverflow;
import kotlinx.coroutines.flow.internal.NullSurrogateKt;
import kotlinx.coroutines.internal.Symbol;

@Metadata(d1 = {"\u0000@\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0005\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\b\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0002\b\u0004\u001a\u001f\u0010\u0006\u001a\b\u0012\u0004\u0012\u0002H\b0\u0007\"\u0004\b\u0000\u0010\b2\u0006\u0010\t\u001a\u0002H\b¢\u0006\u0002\u0010\n\u001a6\u0010\u000b\u001a\b\u0012\u0004\u0012\u0002H\b0\f\"\u0004\b\u0000\u0010\b*\b\u0012\u0004\u0012\u0002H\b0\r2\u0006\u0010\u000e\u001a\u00020\u000f2\u0006\u0010\u0010\u001a\u00020\u00112\u0006\u0010\u0012\u001a\u00020\u0013H\u0000\u001a2\u0010\u0014\u001a\u0002H\b\"\u0004\b\u0000\u0010\b*\b\u0012\u0004\u0012\u0002H\b0\u00072\u0012\u0010\u0015\u001a\u000e\u0012\u0004\u0012\u0002H\b\u0012\u0004\u0012\u0002H\b0\u0016H\b¢\u0006\u0002\u0010\u0017\u001a\u001a\u0010\u0018\u001a\u00020\u0019*\b\u0012\u0004\u0012\u00020\u00110\u00072\u0006\u0010\u001a\u001a\u00020\u0011H\u0000\u001a-\u0010\u001b\u001a\u00020\u0019\"\u0004\b\u0000\u0010\b*\b\u0012\u0004\u0012\u0002H\b0\u00072\u0012\u0010\u0015\u001a\u000e\u0012\u0004\u0012\u0002H\b\u0012\u0004\u0012\u0002H\b0\u0016H\b\u001a2\u0010\u001c\u001a\u0002H\b\"\u0004\b\u0000\u0010\b*\b\u0012\u0004\u0012\u0002H\b0\u00072\u0012\u0010\u0015\u001a\u000e\u0012\u0004\u0012\u0002H\b\u0012\u0004\u0012\u0002H\b0\u0016H\b¢\u0006\u0002\u0010\u0017\"\u0016\u0010\u0000\u001a\u00020\u00018\u0002X\u0004¢\u0006\b\n\u0000\u0012\u0004\b\u0002\u0010\u0003\"\u0016\u0010\u0004\u001a\u00020\u00018\u0002X\u0004¢\u0006\b\n\u0000\u0012\u0004\b\u0005\u0010\u0003¨\u0006\u001d"}, d2 = {"NONE", "Lkotlinx/coroutines/internal/Symbol;", "getNONE$annotations", "()V", "PENDING", "getPENDING$annotations", "MutableStateFlow", "Lkotlinx/coroutines/flow/MutableStateFlow;", "T", "value", "(Ljava/lang/Object;)Lkotlinx/coroutines/flow/MutableStateFlow;", "fuseStateFlow", "Lkotlinx/coroutines/flow/Flow;", "Lkotlinx/coroutines/flow/StateFlow;", "context", "Lkotlin/coroutines/CoroutineContext;", "capacity", "", "onBufferOverflow", "Lkotlinx/coroutines/channels/BufferOverflow;", "getAndUpdate", "function", "Lkotlin/Function1;", "(Lkotlinx/coroutines/flow/MutableStateFlow;Lkotlin/jvm/functions/Function1;)Ljava/lang/Object;", "increment", "", "delta", "update", "updateAndGet", "kotlinx-coroutines-core"}, k = 2, mv = {1, 5, 1}, xi = 48)
/* compiled from: StateFlow.kt */
public final class StateFlowKt {
    /* access modifiers changed from: private */
    public static final Symbol NONE = new Symbol("NONE");
    /* access modifiers changed from: private */
    public static final Symbol PENDING = new Symbol("PENDING");

    private static /* synthetic */ void getNONE$annotations() {
    }

    private static /* synthetic */ void getPENDING$annotations() {
    }

    public static final <T> MutableStateFlow<T> MutableStateFlow(T value) {
        return new StateFlowImpl<>(value == null ? NullSurrogateKt.NULL : value);
    }

    public static final <T> T updateAndGet(MutableStateFlow<T> $this$updateAndGet, Function1<? super T, ? extends T> function) {
        Object prevValue;
        Object nextValue;
        do {
            prevValue = $this$updateAndGet.getValue();
            nextValue = function.invoke(prevValue);
        } while (!$this$updateAndGet.compareAndSet(prevValue, nextValue));
        return nextValue;
    }

    public static final <T> T getAndUpdate(MutableStateFlow<T> $this$getAndUpdate, Function1<? super T, ? extends T> function) {
        Object prevValue;
        do {
            prevValue = $this$getAndUpdate.getValue();
        } while (!$this$getAndUpdate.compareAndSet(prevValue, function.invoke(prevValue)));
        return prevValue;
    }

    public static final <T> void update(MutableStateFlow<T> $this$update, Function1<? super T, ? extends T> function) {
        Object prevValue;
        do {
            prevValue = $this$update.getValue();
        } while (!$this$update.compareAndSet(prevValue, function.invoke(prevValue)));
    }

    public static final void increment(MutableStateFlow<Integer> $this$increment, int delta) {
        Integer value;
        MutableStateFlow $this$update$iv = $this$increment;
        do {
            value = $this$update$iv.getValue();
        } while (!$this$update$iv.compareAndSet(value, Integer.valueOf(value.intValue() + delta)));
    }

    public static final <T> Flow<T> fuseStateFlow(StateFlow<? extends T> $this$fuseStateFlow, CoroutineContext context, int capacity, BufferOverflow onBufferOverflow) {
        boolean z = true;
        if (DebugKt.getASSERTIONS_ENABLED()) {
            if ((capacity != -1 ? 1 : 0) == 0) {
                throw new AssertionError();
            }
        }
        if (capacity < 0 || capacity > 1) {
            z = false;
        }
        if ((z || capacity == -2) && onBufferOverflow == BufferOverflow.DROP_OLDEST) {
            return $this$fuseStateFlow;
        }
        return SharedFlowKt.fuseSharedFlow($this$fuseStateFlow, context, capacity, onBufferOverflow);
    }
}
