package org.coeye.client;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.util.Log;
import kotlin.Metadata;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.DebugKt;

@Metadata(d1 = {"\u00004\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u000b\n\u0002\b\u0002\n\u0002\u0010\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0005\u0018\u0000 \u00122\u00020\u0001:\u0002\u0012\u0013B\u0017\u0012\u0006\u0010\u0002\u001a\u00020\u0003\u0012\b\u0010\u0004\u001a\u0004\u0018\u00010\u0005¢\u0006\u0002\u0010\u0006J\u0018\u0010\f\u001a\u00020\r2\u0006\u0010\u0002\u001a\u00020\u00032\u0006\u0010\u000e\u001a\u00020\u000fH\u0016J\u0006\u0010\u0010\u001a\u00020\rJ\u0006\u0010\u0011\u001a\u00020\rR\u000e\u0010\u0007\u001a\u00020\bX\u0004¢\u0006\u0002\n\u0000R\u000e\u0010\u0002\u001a\u00020\u0003X\u0004¢\u0006\u0002\n\u0000R\u0010\u0010\u0004\u001a\u0004\u0018\u00010\u0005X\u0004¢\u0006\u0002\n\u0000R\u0011\u0010\t\u001a\u00020\n8F¢\u0006\u0006\u001a\u0004\b\t\u0010\u000b¨\u0006\u0014"}, d2 = {"Lorg/coeye/client/NetworkManager;", "Landroid/content/BroadcastReceiver;", "context", "Landroid/content/Context;", "handler", "Lorg/coeye/client/NetworkManager$NetworkHandler;", "(Landroid/content/Context;Lorg/coeye/client/NetworkManager$NetworkHandler;)V", "connectivityManager", "Landroid/net/ConnectivityManager;", "isOnline", "", "()Z", "onReceive", "", "intent", "Landroid/content/Intent;", "start", "stop", "Companion", "NetworkHandler", "app_regularDebug"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* compiled from: NetworkManager.kt */
public final class NetworkManager extends BroadcastReceiver {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    private static final String TAG = NetworkManager.class.getSimpleName();
    private final ConnectivityManager connectivityManager;
    private final Context context;
    private final NetworkHandler handler;

    @Metadata(d1 = {"\u0000\u0016\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0000\n\u0002\u0010\u0002\n\u0000\n\u0002\u0010\u000b\n\u0000\bf\u0018\u00002\u00020\u0001J\u0010\u0010\u0002\u001a\u00020\u00032\u0006\u0010\u0004\u001a\u00020\u0005H&¨\u0006\u0006"}, d2 = {"Lorg/coeye/client/NetworkManager$NetworkHandler;", "", "onNetworkUpdate", "", "isOnline", "", "app_regularDebug"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* compiled from: NetworkManager.kt */
    public interface NetworkHandler {
        void onNetworkUpdate(boolean z);
    }

    public NetworkManager(Context context2, NetworkHandler handler2) {
        Intrinsics.checkNotNullParameter(context2, "context");
        this.context = context2;
        this.handler = handler2;
        Object systemService = context2.getSystemService("connectivity");
        if (systemService != null) {
            this.connectivityManager = (ConnectivityManager) systemService;
            return;
        }
        throw new NullPointerException("null cannot be cast to non-null type android.net.ConnectivityManager");
    }

    public final boolean isOnline() {
        NetworkInfo activeNetwork = this.connectivityManager.getActiveNetworkInfo();
        return activeNetwork != null && activeNetwork.isConnectedOrConnecting();
    }

    public final void start() {
        IntentFilter filter = new IntentFilter();
        filter.addAction("android.net.conn.CONNECTIVITY_CHANGE");
        this.context.registerReceiver(this, filter);
    }

    public final void stop() {
        this.context.unregisterReceiver(this);
    }

    public void onReceive(Context context2, Intent intent) {
        Intrinsics.checkNotNullParameter(context2, "context");
        Intrinsics.checkNotNullParameter(intent, "intent");
        if (Intrinsics.areEqual((Object) intent.getAction(), (Object) "android.net.conn.CONNECTIVITY_CHANGE") && this.handler != null) {
            boolean isOnline = isOnline();
            Log.i(TAG, Intrinsics.stringPlus("network ", isOnline ? DebugKt.DEBUG_PROPERTY_VALUE_ON : DebugKt.DEBUG_PROPERTY_VALUE_OFF));
            this.handler.onNetworkUpdate(isOnline);
        }
    }

    @Metadata(d1 = {"\u0000\u0014\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0010\u000e\n\u0002\b\u0002\b\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002R\u0016\u0010\u0003\u001a\n \u0005*\u0004\u0018\u00010\u00040\u0004X\u0004¢\u0006\u0002\n\u0000¨\u0006\u0006"}, d2 = {"Lorg/coeye/client/NetworkManager$Companion;", "", "()V", "TAG", "", "kotlin.jvm.PlatformType", "app_regularDebug"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* compiled from: NetworkManager.kt */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }
    }
}
