package org.coeye.client;

import android.app.Notification;
import android.app.PendingIntent;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.os.IBinder;
import android.os.PowerManager;
import android.util.Log;
import androidx.core.app.NotificationCompat;
import androidx.core.content.ContextCompat;
import androidx.preference.PreferenceManager;
import kotlin.Metadata;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import org.coeye.client.StatusActivity;

@Metadata(d1 = {"\u00008\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u0002\n\u0002\b\u0002\n\u0002\u0010\b\n\u0002\b\u0005\u0018\u0000 \u00132\u00020\u0001:\u0002\u0013\u0014B\u0005¢\u0006\u0002\u0010\u0002J\u0012\u0010\b\u001a\u0004\u0018\u00010\t2\u0006\u0010\n\u001a\u00020\u000bH\u0016J\b\u0010\f\u001a\u00020\rH\u0017J\b\u0010\u000e\u001a\u00020\rH\u0016J\"\u0010\u000f\u001a\u00020\u00102\b\u0010\n\u001a\u0004\u0018\u00010\u000b2\u0006\u0010\u0011\u001a\u00020\u00102\u0006\u0010\u0012\u001a\u00020\u0010H\u0017R\u0010\u0010\u0003\u001a\u0004\u0018\u00010\u0004X\u000e¢\u0006\u0002\n\u0000R\u0014\u0010\u0005\u001a\b\u0018\u00010\u0006R\u00020\u0007X\u000e¢\u0006\u0002\n\u0000¨\u0006\u0015"}, d2 = {"Lorg/coeye/client/TrackingService;", "Landroid/app/Service;", "()V", "trackingController", "Lorg/coeye/client/TrackingController;", "wakeLock", "Landroid/os/PowerManager$WakeLock;", "Landroid/os/PowerManager;", "onBind", "Landroid/os/IBinder;", "intent", "Landroid/content/Intent;", "onCreate", "", "onDestroy", "onStartCommand", "", "flags", "startId", "Companion", "HideNotificationService", "app_regularDebug"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* compiled from: TrackingService.kt */
public final class TrackingService extends Service {
    public static final String ACTION_STARTED = "org.coeye.action.SERVICE_STARTED";
    public static final String ACTION_STOPPED = "org.coeye.action.SERVICE_STOPPED";
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    private static final int NOTIFICATION_ID = 1;
    private static final String TAG = TrackingService.class.getSimpleName();
    private TrackingController trackingController;
    private PowerManager.WakeLock wakeLock;

    @Metadata(d1 = {"\u0000&\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u0002\n\u0000\n\u0002\u0010\b\n\u0002\b\u0003\u0018\u00002\u00020\u0001B\u0005¢\u0006\u0002\u0010\u0002J\u0012\u0010\u0003\u001a\u0004\u0018\u00010\u00042\u0006\u0010\u0005\u001a\u00020\u0006H\u0016J\b\u0010\u0007\u001a\u00020\bH\u0016J\"\u0010\t\u001a\u00020\n2\b\u0010\u0005\u001a\u0004\u0018\u00010\u00062\u0006\u0010\u000b\u001a\u00020\n2\u0006\u0010\f\u001a\u00020\nH\u0016¨\u0006\r"}, d2 = {"Lorg/coeye/client/TrackingService$HideNotificationService;", "Landroid/app/Service;", "()V", "onBind", "Landroid/os/IBinder;", "intent", "Landroid/content/Intent;", "onCreate", "", "onStartCommand", "", "flags", "startId", "app_regularDebug"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* compiled from: TrackingService.kt */
    public static final class HideNotificationService extends Service {
        public IBinder onBind(Intent intent) {
            Intrinsics.checkNotNullParameter(intent, "intent");
            return null;
        }

        public void onCreate() {
            startForeground(1, TrackingService.Companion.createNotification(this));
            stopForeground(true);
        }

        public int onStartCommand(Intent intent, int flags, int startId) {
            stopSelfResult(startId);
            return 2;
        }
    }

    public void onCreate() {
        startForeground(1, Companion.createNotification(this));
        Log.i(TAG, "service create");
        sendBroadcast(new Intent(ACTION_STARTED));
        StatusActivity.Companion companion = StatusActivity.Companion;
        String string = getString(R.string.status_service_create);
        Intrinsics.checkNotNullExpressionValue(string, "getString(R.string.status_service_create)");
        companion.addMessage(string);
        if (ContextCompat.checkSelfPermission(this, "android.permission.ACCESS_FINE_LOCATION") == 0) {
            if (PreferenceManager.getDefaultSharedPreferences(this).getBoolean(MainFragment.KEY_WAKELOCK, true)) {
                Object systemService = getSystemService("power");
                if (systemService != null) {
                    PowerManager.WakeLock newWakeLock = ((PowerManager) systemService).newWakeLock(1, getClass().getName());
                    this.wakeLock = newWakeLock;
                    if (newWakeLock != null) {
                        newWakeLock.acquire();
                    }
                } else {
                    throw new NullPointerException("null cannot be cast to non-null type android.os.PowerManager");
                }
            }
            TrackingController trackingController2 = new TrackingController(this);
            this.trackingController = trackingController2;
            trackingController2.start();
        }
        if (Build.VERSION.SDK_INT < 26) {
            ContextCompat.startForegroundService(this, new Intent(this, HideNotificationService.class));
        }
    }

    public IBinder onBind(Intent intent) {
        Intrinsics.checkNotNullParameter(intent, "intent");
        return null;
    }

    public int onStartCommand(Intent intent, int flags, int startId) {
        WakefulBroadcastReceiver.Companion.completeWakefulIntent(intent);
        return 1;
    }

    public void onDestroy() {
        PowerManager.WakeLock wakeLock2;
        boolean z = true;
        stopForeground(true);
        Log.i(TAG, "service destroy");
        sendBroadcast(new Intent(ACTION_STOPPED));
        StatusActivity.Companion companion = StatusActivity.Companion;
        String string = getString(R.string.status_service_destroy);
        Intrinsics.checkNotNullExpressionValue(string, "getString(R.string.status_service_destroy)");
        companion.addMessage(string);
        PowerManager.WakeLock wakeLock3 = this.wakeLock;
        if (wakeLock3 == null || !wakeLock3.isHeld()) {
            z = false;
        }
        if (z && (wakeLock2 = this.wakeLock) != null) {
            wakeLock2.release();
        }
        TrackingController trackingController2 = this.trackingController;
        if (trackingController2 != null) {
            trackingController2.stop();
        }
    }

    @Metadata(d1 = {"\u0000(\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0010\u000e\n\u0002\b\u0002\n\u0002\u0010\b\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\b\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002J\u0010\u0010\n\u001a\u00020\u000b2\u0006\u0010\f\u001a\u00020\rH\u0003R\u000e\u0010\u0003\u001a\u00020\u0004XT¢\u0006\u0002\n\u0000R\u000e\u0010\u0005\u001a\u00020\u0004XT¢\u0006\u0002\n\u0000R\u000e\u0010\u0006\u001a\u00020\u0007XT¢\u0006\u0002\n\u0000R\u0016\u0010\b\u001a\n \t*\u0004\u0018\u00010\u00040\u0004X\u0004¢\u0006\u0002\n\u0000¨\u0006\u000e"}, d2 = {"Lorg/coeye/client/TrackingService$Companion;", "", "()V", "ACTION_STARTED", "", "ACTION_STOPPED", "NOTIFICATION_ID", "", "TAG", "kotlin.jvm.PlatformType", "createNotification", "Landroid/app/Notification;", "context", "Landroid/content/Context;", "app_regularDebug"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* compiled from: TrackingService.kt */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        /* access modifiers changed from: private */
        public final Notification createNotification(Context context) {
            int flags;
            NotificationCompat.Builder builder = new NotificationCompat.Builder(context, MainApplication.PRIMARY_CHANNEL).setSmallIcon((int) R.drawable.ic_stat_notify).setPriority(-1).setCategory(NotificationCompat.CATEGORY_SERVICE);
            Intrinsics.checkNotNullExpressionValue(builder, "Builder(context, MainApp…nCompat.CATEGORY_SERVICE)");
            Intent intent = new Intent(context, MainActivity.class);
            builder.setContentTitle(context.getString(R.string.settings_status_on_summary)).setTicker(context.getString(R.string.settings_status_on_summary)).setColor(ContextCompat.getColor(context, R.color.primary_dark));
            if (Build.VERSION.SDK_INT >= 31) {
                flags = 67108864;
            } else {
                flags = 134217728;
            }
            builder.setContentIntent(PendingIntent.getActivity(context, 0, intent, flags));
            Notification build = builder.build();
            Intrinsics.checkNotNullExpressionValue(build, "builder.build()");
            return build;
        }
    }
}
