package org.coeye.client;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.PowerManager;
import android.util.SparseArray;
import androidx.core.content.ContextCompat;
import kotlin.Metadata;
import kotlin.Unit;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;

@Metadata(d1 = {"\u0000\f\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\b\u0003\b&\u0018\u0000 \u00032\u00020\u0001:\u0001\u0003B\u0005¢\u0006\u0002\u0010\u0002¨\u0006\u0004"}, d2 = {"Lorg/coeye/client/WakefulBroadcastReceiver;", "Landroid/content/BroadcastReceiver;", "()V", "Companion", "app_regularDebug"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* compiled from: WakefulBroadcastReceiver.kt */
public abstract class WakefulBroadcastReceiver extends BroadcastReceiver {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    private static final String EXTRA_WAKE_LOCK_ID = "android.support.content.wakelockid";
    /* access modifiers changed from: private */
    public static final SparseArray<PowerManager.WakeLock> activeWakeLocks = new SparseArray<>();
    /* access modifiers changed from: private */
    public static int nextId = 1;

    @Metadata(d1 = {"\u0000>\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0010\u000e\n\u0000\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\b\n\u0000\n\u0002\u0010\u000b\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\b\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002J\u0010\u0010\u000b\u001a\u00020\f2\b\u0010\r\u001a\u0004\u0018\u00010\u000eJ\u0016\u0010\u000f\u001a\u00020\u00102\u0006\u0010\u0011\u001a\u00020\u00122\u0006\u0010\r\u001a\u00020\u000eR\u000e\u0010\u0003\u001a\u00020\u0004XT¢\u0006\u0002\n\u0000R\u0018\u0010\u0005\u001a\f\u0012\b\u0012\u00060\u0007R\u00020\b0\u0006X\u0004¢\u0006\u0002\n\u0000R\u000e\u0010\t\u001a\u00020\nX\u000e¢\u0006\u0002\n\u0000¨\u0006\u0013"}, d2 = {"Lorg/coeye/client/WakefulBroadcastReceiver$Companion;", "", "()V", "EXTRA_WAKE_LOCK_ID", "", "activeWakeLocks", "Landroid/util/SparseArray;", "Landroid/os/PowerManager$WakeLock;", "Landroid/os/PowerManager;", "nextId", "", "completeWakefulIntent", "", "intent", "Landroid/content/Intent;", "startWakefulForegroundService", "", "context", "Landroid/content/Context;", "app_regularDebug"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* compiled from: WakefulBroadcastReceiver.kt */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final void startWakefulForegroundService(Context context, Intent intent) {
            Intrinsics.checkNotNullParameter(context, "context");
            Intrinsics.checkNotNullParameter(intent, "intent");
            synchronized (WakefulBroadcastReceiver.activeWakeLocks) {
                int id = WakefulBroadcastReceiver.nextId;
                Companion companion = WakefulBroadcastReceiver.Companion;
                WakefulBroadcastReceiver.nextId = WakefulBroadcastReceiver.nextId + 1;
                if (WakefulBroadcastReceiver.nextId <= 0) {
                    Companion companion2 = WakefulBroadcastReceiver.Companion;
                    WakefulBroadcastReceiver.nextId = 1;
                }
                intent.putExtra(WakefulBroadcastReceiver.EXTRA_WAKE_LOCK_ID, id);
                ContextCompat.startForegroundService(context, intent);
                Object systemService = context.getSystemService("power");
                if (systemService != null) {
                    PowerManager.WakeLock wakeLock = ((PowerManager) systemService).newWakeLock(1, WakefulBroadcastReceiver.class.getSimpleName());
                    wakeLock.setReferenceCounted(false);
                    wakeLock.acquire(60000);
                    WakefulBroadcastReceiver.activeWakeLocks.put(id, wakeLock);
                    Unit unit = Unit.INSTANCE;
                } else {
                    throw new NullPointerException("null cannot be cast to non-null type android.os.PowerManager");
                }
            }
        }

        public final boolean completeWakefulIntent(Intent intent) {
            int id = intent == null ? 0 : intent.getIntExtra(WakefulBroadcastReceiver.EXTRA_WAKE_LOCK_ID, 0);
            if (id == 0) {
                return false;
            }
            synchronized (WakefulBroadcastReceiver.activeWakeLocks) {
                PowerManager.WakeLock wakeLock = (PowerManager.WakeLock) WakefulBroadcastReceiver.activeWakeLocks.get(id);
                if (wakeLock == null) {
                    return true;
                }
                wakeLock.release();
                WakefulBroadcastReceiver.activeWakeLocks.remove(id);
                return true;
            }
        }
    }
}
