package org.commonmark.internal;

import org.commonmark.internal.util.Parsing;
import org.commonmark.node.Block;
import org.commonmark.node.BlockQuote;
import org.commonmark.parser.block.AbstractBlockParser;
import org.commonmark.parser.block.AbstractBlockParserFactory;
import org.commonmark.parser.block.BlockContinue;
import org.commonmark.parser.block.BlockStart;
import org.commonmark.parser.block.MatchedBlockParser;
import org.commonmark.parser.block.ParserState;

public class BlockQuoteParser extends AbstractBlockParser {
    private final BlockQuote block = new BlockQuote();

    public boolean isContainer() {
        return true;
    }

    public boolean canContain(Block block2) {
        return true;
    }

    public BlockQuote getBlock() {
        return this.block;
    }

    public BlockContinue tryContinue(ParserState state) {
        int nextNonSpace = state.getNextNonSpaceIndex();
        if (!isMarker(state, nextNonSpace)) {
            return BlockContinue.none();
        }
        int newColumn = state.getColumn() + state.getIndent() + 1;
        if (Parsing.isSpaceOrTab(state.getLine(), nextNonSpace + 1)) {
            newColumn++;
        }
        return BlockContinue.atColumn(newColumn);
    }

    /* access modifiers changed from: private */
    public static boolean isMarker(ParserState state, int index) {
        CharSequence line = state.getLine();
        return state.getIndent() < Parsing.CODE_BLOCK_INDENT && index < line.length() && line.charAt(index) == '>';
    }

    public static class Factory extends AbstractBlockParserFactory {
        public BlockStart tryStart(ParserState state, MatchedBlockParser matchedBlockParser) {
            int nextNonSpace = state.getNextNonSpaceIndex();
            if (!BlockQuoteParser.isMarker(state, nextNonSpace)) {
                return BlockStart.none();
            }
            int newColumn = state.getColumn() + state.getIndent() + 1;
            if (Parsing.isSpaceOrTab(state.getLine(), nextNonSpace + 1)) {
                newColumn++;
            }
            return BlockStart.of(new BlockQuoteParser()).atColumn(newColumn);
        }
    }
}
