package org.commonmark.internal;

import org.commonmark.internal.util.Parsing;
import org.commonmark.node.Block;
import org.commonmark.node.Heading;
import org.commonmark.parser.InlineParser;
import org.commonmark.parser.block.AbstractBlockParser;
import org.commonmark.parser.block.AbstractBlockParserFactory;
import org.commonmark.parser.block.BlockContinue;
import org.commonmark.parser.block.BlockStart;
import org.commonmark.parser.block.MatchedBlockParser;
import org.commonmark.parser.block.ParserState;

public class HeadingParser extends AbstractBlockParser {
    private final Heading block;
    private final String content;

    public HeadingParser(int level, String content2) {
        Heading heading = new Heading();
        this.block = heading;
        heading.setLevel(level);
        this.content = content2;
    }

    public Block getBlock() {
        return this.block;
    }

    public BlockContinue tryContinue(ParserState parserState) {
        return BlockContinue.none();
    }

    public void parseInlines(InlineParser inlineParser) {
        inlineParser.parse(this.content, this.block);
    }

    public static class Factory extends AbstractBlockParserFactory {
        public BlockStart tryStart(ParserState state, MatchedBlockParser matchedBlockParser) {
            CharSequence paragraph;
            if (state.getIndent() >= Parsing.CODE_BLOCK_INDENT) {
                return BlockStart.none();
            }
            CharSequence line = state.getLine();
            int nextNonSpace = state.getNextNonSpaceIndex();
            HeadingParser atxHeading = HeadingParser.getAtxHeading(line, nextNonSpace);
            if (atxHeading != null) {
                return BlockStart.of(atxHeading).atIndex(line.length());
            }
            int setextHeadingLevel = HeadingParser.getSetextHeadingLevel(line, nextNonSpace);
            if (setextHeadingLevel <= 0 || (paragraph = matchedBlockParser.getParagraphContent()) == null) {
                return BlockStart.none();
            }
            return BlockStart.of(new HeadingParser(setextHeadingLevel, paragraph.toString())).atIndex(line.length()).replaceActiveBlockParser();
        }
    }

    /* access modifiers changed from: private */
    public static HeadingParser getAtxHeading(CharSequence line, int index) {
        int level = Parsing.skip('#', line, index, line.length()) - index;
        if (level == 0 || level > 6) {
            return null;
        }
        int start = index + level;
        if (start >= line.length()) {
            return new HeadingParser(level, "");
        }
        char next = line.charAt(start);
        if (next != ' ' && next != 9) {
            return null;
        }
        int beforeSpace = Parsing.skipSpaceTabBackwards(line, line.length() - 1, start);
        int beforeHash = Parsing.skipBackwards('#', line, beforeSpace, start);
        int beforeTrailer = Parsing.skipSpaceTabBackwards(line, beforeHash, start);
        if (beforeTrailer != beforeHash) {
            return new HeadingParser(level, line.subSequence(start, beforeTrailer + 1).toString());
        }
        return new HeadingParser(level, line.subSequence(start, beforeSpace + 1).toString());
    }

    /* access modifiers changed from: private */
    public static int getSetextHeadingLevel(CharSequence line, int index) {
        switch (line.charAt(index)) {
            case '-':
                break;
            case '=':
                if (isSetextHeadingRest(line, index + 1, '=')) {
                    return 1;
                }
                break;
            default:
                return 0;
        }
        if (isSetextHeadingRest(line, index + 1, '-')) {
            return 2;
        }
        return 0;
    }

    private static boolean isSetextHeadingRest(CharSequence line, int index, char marker) {
        return Parsing.skipSpaceTab(line, Parsing.skip(marker, line, index, line.length()), line.length()) >= line.length();
    }
}
