package org.commonmark.internal;

import org.commonmark.internal.util.Parsing;
import org.commonmark.node.Block;
import org.commonmark.node.Paragraph;
import org.commonmark.parser.InlineParser;
import org.commonmark.parser.block.AbstractBlockParser;
import org.commonmark.parser.block.BlockContinue;
import org.commonmark.parser.block.ParserState;

public class ParagraphParser extends AbstractBlockParser {
    private final Paragraph block = new Paragraph();
    private BlockContent content = new BlockContent();

    public Block getBlock() {
        return this.block;
    }

    public BlockContinue tryContinue(ParserState state) {
        if (!state.isBlank()) {
            return BlockContinue.atIndex(state.getIndex());
        }
        return BlockContinue.none();
    }

    public void addLine(CharSequence line) {
        this.content.add(line);
    }

    public void closeBlock() {
    }

    public void closeBlock(ReferenceParser inlineParser) {
        String contentString = this.content.getString();
        boolean hasReferenceDefs = false;
        while (contentString.length() > 3 && contentString.charAt(0) == '[') {
            int parseReference = inlineParser.parseReference(contentString);
            int pos = parseReference;
            if (parseReference == 0) {
                break;
            }
            contentString = contentString.substring(pos);
            hasReferenceDefs = true;
        }
        if (!hasReferenceDefs || !Parsing.isBlank(contentString)) {
            this.content = new BlockContent(contentString);
            return;
        }
        this.block.unlink();
        this.content = null;
    }

    public void parseInlines(InlineParser inlineParser) {
        BlockContent blockContent = this.content;
        if (blockContent != null) {
            inlineParser.parse(blockContent.getString(), this.block);
        }
    }

    public String getContentString() {
        return this.content.getString();
    }
}
