package org.commonmark.internal;

import java.util.Iterator;
import java.util.LinkedList;
import java.util.ListIterator;
import org.commonmark.node.Text;
import org.commonmark.parser.delimiter.DelimiterProcessor;
import org.commonmark.parser.delimiter.DelimiterRun;

class StaggeredDelimiterProcessor implements DelimiterProcessor {
    private final char delim;
    private int minLength = 0;
    private LinkedList<DelimiterProcessor> processors = new LinkedList<>();

    StaggeredDelimiterProcessor(char delim2) {
        this.delim = delim2;
    }

    public char getOpeningCharacter() {
        return this.delim;
    }

    public char getClosingCharacter() {
        return this.delim;
    }

    public int getMinLength() {
        return this.minLength;
    }

    /* access modifiers changed from: package-private */
    public void add(DelimiterProcessor dp) {
        int pLen;
        int len = dp.getMinLength();
        ListIterator<DelimiterProcessor> it = this.processors.listIterator();
        boolean added = false;
        do {
            if (it.hasNext()) {
                pLen = it.next().getMinLength();
                if (len > pLen) {
                    it.previous();
                    it.add(dp);
                    added = true;
                }
            }
            if (!added) {
                this.processors.add(dp);
                this.minLength = len;
                return;
            }
            return;
        } while (len != pLen);
        throw new IllegalArgumentException("Cannot add two delimiter processors for char '" + this.delim + "' and minimum length " + len);
    }

    private DelimiterProcessor findProcessor(int len) {
        Iterator it = this.processors.iterator();
        while (it.hasNext()) {
            DelimiterProcessor p = (DelimiterProcessor) it.next();
            if (p.getMinLength() <= len) {
                return p;
            }
        }
        return this.processors.getFirst();
    }

    public int getDelimiterUse(DelimiterRun opener, DelimiterRun closer) {
        return findProcessor(opener.length()).getDelimiterUse(opener, closer);
    }

    public void process(Text opener, Text closer, int delimiterUse) {
        findProcessor(delimiterUse).process(opener, closer, delimiterUse);
    }
}
