package org.commonmark.internal;

import org.commonmark.node.Block;
import org.commonmark.node.ThematicBreak;
import org.commonmark.parser.block.AbstractBlockParser;
import org.commonmark.parser.block.AbstractBlockParserFactory;
import org.commonmark.parser.block.BlockContinue;
import org.commonmark.parser.block.BlockStart;
import org.commonmark.parser.block.MatchedBlockParser;
import org.commonmark.parser.block.ParserState;

public class ThematicBreakParser extends AbstractBlockParser {
    private final ThematicBreak block = new ThematicBreak();

    public Block getBlock() {
        return this.block;
    }

    public BlockContinue tryContinue(ParserState state) {
        return BlockContinue.none();
    }

    public static class Factory extends AbstractBlockParserFactory {
        public BlockStart tryStart(ParserState state, MatchedBlockParser matchedBlockParser) {
            if (state.getIndent() >= 4) {
                return BlockStart.none();
            }
            int nextNonSpace = state.getNextNonSpaceIndex();
            CharSequence line = state.getLine();
            if (!ThematicBreakParser.isThematicBreak(line, nextNonSpace)) {
                return BlockStart.none();
            }
            return BlockStart.of(new ThematicBreakParser()).atIndex(line.length());
        }
    }

    /* access modifiers changed from: private */
    public static boolean isThematicBreak(CharSequence line, int index) {
        int dashes = 0;
        int underscores = 0;
        int asterisks = 0;
        int length = line.length();
        for (int i = index; i < length; i++) {
            switch (line.charAt(i)) {
                case 9:
                case ' ':
                    break;
                case '*':
                    asterisks++;
                    break;
                case '-':
                    dashes++;
                    break;
                case '_':
                    underscores++;
                    break;
                default:
                    return false;
            }
        }
        if ((dashes >= 3 && underscores == 0 && asterisks == 0) || ((underscores >= 3 && dashes == 0 && asterisks == 0) || (asterisks >= 3 && dashes == 0 && underscores == 0))) {
            return true;
        }
        return false;
    }
}
