package org.commonmark.internal.inline;

import org.commonmark.node.Emphasis;
import org.commonmark.node.Node;
import org.commonmark.node.StrongEmphasis;
import org.commonmark.node.Text;
import org.commonmark.parser.delimiter.DelimiterProcessor;
import org.commonmark.parser.delimiter.DelimiterRun;

public abstract class EmphasisDelimiterProcessor implements DelimiterProcessor {
    private final char delimiterChar;

    protected EmphasisDelimiterProcessor(char delimiterChar2) {
        this.delimiterChar = delimiterChar2;
    }

    public char getOpeningCharacter() {
        return this.delimiterChar;
    }

    public char getClosingCharacter() {
        return this.delimiterChar;
    }

    public int getMinLength() {
        return 1;
    }

    public int getDelimiterUse(DelimiterRun opener, DelimiterRun closer) {
        if ((opener.canClose() || closer.canOpen()) && (opener.originalLength() + closer.originalLength()) % 3 == 0) {
            return 0;
        }
        if (opener.length() < 2 || closer.length() < 2) {
            return 1;
        }
        return 2;
    }

    public void process(Text opener, Text closer, int delimiterUse) {
        Node emphasis;
        String singleDelimiter = String.valueOf(getOpeningCharacter());
        if (delimiterUse == 1) {
            emphasis = new Emphasis(singleDelimiter);
        } else {
            emphasis = new StrongEmphasis(singleDelimiter + singleDelimiter);
        }
        Node tmp = opener.getNext();
        while (tmp != null && tmp != closer) {
            Node next = tmp.getNext();
            emphasis.appendChild(tmp);
            tmp = next;
        }
        opener.insertAfter(emphasis);
    }
}
