package org.commonmark.node;

public abstract class Node {
    private Node firstChild = null;
    private Node lastChild = null;
    private Node next = null;
    private Node parent = null;
    private Node prev = null;

    public abstract void accept(Visitor visitor);

    public Node getNext() {
        return this.next;
    }

    public Node getPrevious() {
        return this.prev;
    }

    public Node getFirstChild() {
        return this.firstChild;
    }

    public Node getLastChild() {
        return this.lastChild;
    }

    public Node getParent() {
        return this.parent;
    }

    /* access modifiers changed from: protected */
    public void setParent(Node parent2) {
        this.parent = parent2;
    }

    public void appendChild(Node child) {
        child.unlink();
        child.setParent(this);
        Node node = this.lastChild;
        if (node != null) {
            node.next = child;
            child.prev = node;
            this.lastChild = child;
            return;
        }
        this.firstChild = child;
        this.lastChild = child;
    }

    public void prependChild(Node child) {
        child.unlink();
        child.setParent(this);
        Node node = this.firstChild;
        if (node != null) {
            node.prev = child;
            child.next = node;
            this.firstChild = child;
            return;
        }
        this.firstChild = child;
        this.lastChild = child;
    }

    public void unlink() {
        Node node = this.prev;
        if (node != null) {
            node.next = this.next;
        } else {
            Node node2 = this.parent;
            if (node2 != null) {
                node2.firstChild = this.next;
            }
        }
        Node node3 = this.next;
        if (node3 != null) {
            node3.prev = node;
        } else {
            Node node4 = this.parent;
            if (node4 != null) {
                node4.lastChild = node;
            }
        }
        this.parent = null;
        this.next = null;
        this.prev = null;
    }

    public void insertAfter(Node sibling) {
        sibling.unlink();
        Node node = this.next;
        sibling.next = node;
        if (node != null) {
            node.prev = sibling;
        }
        sibling.prev = this;
        this.next = sibling;
        Node node2 = this.parent;
        sibling.parent = node2;
        if (sibling.next == null) {
            node2.lastChild = sibling;
        }
    }

    public void insertBefore(Node sibling) {
        sibling.unlink();
        Node node = this.prev;
        sibling.prev = node;
        if (node != null) {
            node.next = sibling;
        }
        sibling.next = this;
        this.prev = sibling;
        Node node2 = this.parent;
        sibling.parent = node2;
        if (sibling.prev == null) {
            node2.firstChild = sibling;
        }
    }

    public String toString() {
        return getClass().getSimpleName() + "{" + toStringAttributes() + "}";
    }

    /* access modifiers changed from: protected */
    public String toStringAttributes() {
        return "";
    }
}
