package org.commonmark.renderer.html;

import java.io.IOException;
import java.util.Collections;
import java.util.Map;
import org.commonmark.internal.util.Escaping;

public class HtmlWriter {
    private static final Map<String, String> NO_ATTRIBUTES = Collections.emptyMap();
    private final Appendable buffer;
    private char lastChar = 0;

    public HtmlWriter(Appendable out) {
        this.buffer = out;
    }

    public void raw(String s) {
        append(s);
    }

    public void text(String text) {
        append(Escaping.escapeHtml(text, false));
    }

    public void tag(String name) {
        tag(name, NO_ATTRIBUTES);
    }

    public void tag(String name, Map<String, String> attrs) {
        tag(name, attrs, false);
    }

    public void tag(String name, Map<String, String> attrs, boolean voidElement) {
        append("<");
        append(name);
        if (attrs != null && !attrs.isEmpty()) {
            for (Map.Entry<String, String> attrib : attrs.entrySet()) {
                append(" ");
                append(Escaping.escapeHtml(attrib.getKey(), true));
                append("=\"");
                append(Escaping.escapeHtml(attrib.getValue(), true));
                append("\"");
            }
        }
        if (voidElement) {
            append(" /");
        }
        append(">");
    }

    public void line() {
        char c = this.lastChar;
        if (c != 0 && c != 10) {
            append("\n");
        }
    }

    /* access modifiers changed from: protected */
    public void append(String s) {
        try {
            this.buffer.append(s);
            int length = s.length();
            if (length != 0) {
                this.lastChar = s.charAt(length - 1);
            }
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }
}
