package org.commonmark.renderer.text;

import java.util.ArrayList;
import java.util.List;
import org.commonmark.Extension;
import org.commonmark.internal.renderer.NodeRendererMap;
import org.commonmark.node.Node;
import org.commonmark.renderer.NodeRenderer;
import org.commonmark.renderer.Renderer;

public class TextContentRenderer implements Renderer {
    /* access modifiers changed from: private */
    public final List<TextContentNodeRendererFactory> nodeRendererFactories;
    /* access modifiers changed from: private */
    public final boolean stripNewlines;

    public interface TextContentRendererExtension extends Extension {
        void extend(Builder builder);
    }

    private TextContentRenderer(Builder builder) {
        this.stripNewlines = builder.stripNewlines;
        ArrayList arrayList = new ArrayList(builder.nodeRendererFactories.size() + 1);
        this.nodeRendererFactories = arrayList;
        arrayList.addAll(builder.nodeRendererFactories);
        arrayList.add(new TextContentNodeRendererFactory() {
            public NodeRenderer create(TextContentNodeRendererContext context) {
                return new CoreTextContentNodeRenderer(context);
            }
        });
    }

    public static Builder builder() {
        return new Builder();
    }

    public void render(Node node, Appendable output) {
        new RendererContext(new TextContentWriter(output)).render(node);
    }

    public String render(Node node) {
        StringBuilder sb = new StringBuilder();
        render(node, sb);
        return sb.toString();
    }

    public static class Builder {
        /* access modifiers changed from: private */
        public List<TextContentNodeRendererFactory> nodeRendererFactories = new ArrayList();
        /* access modifiers changed from: private */
        public boolean stripNewlines = false;

        public TextContentRenderer build() {
            return new TextContentRenderer(this);
        }

        public Builder stripNewlines(boolean stripNewlines2) {
            this.stripNewlines = stripNewlines2;
            return this;
        }

        public Builder nodeRendererFactory(TextContentNodeRendererFactory nodeRendererFactory) {
            this.nodeRendererFactories.add(nodeRendererFactory);
            return this;
        }

        public Builder extensions(Iterable<? extends Extension> extensions) {
            for (Extension extension : extensions) {
                if (extension instanceof TextContentRendererExtension) {
                    ((TextContentRendererExtension) extension).extend(this);
                }
            }
            return this;
        }
    }

    private class RendererContext implements TextContentNodeRendererContext {
        private final NodeRendererMap nodeRendererMap;
        private final TextContentWriter textContentWriter;

        private RendererContext(TextContentWriter textContentWriter2) {
            this.nodeRendererMap = new NodeRendererMap();
            this.textContentWriter = textContentWriter2;
            for (int i = TextContentRenderer.this.nodeRendererFactories.size() - 1; i >= 0; i--) {
                this.nodeRendererMap.add(((TextContentNodeRendererFactory) TextContentRenderer.this.nodeRendererFactories.get(i)).create(this));
            }
        }

        public boolean stripNewlines() {
            return TextContentRenderer.this.stripNewlines;
        }

        public TextContentWriter getWriter() {
            return this.textContentWriter;
        }

        public void render(Node node) {
            this.nodeRendererMap.render(node);
        }
    }
}
