package ru.noties.markwon;

import android.content.Context;
import android.widget.TextView;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import org.commonmark.parser.Parser;
import ru.noties.markwon.Markwon;
import ru.noties.markwon.MarkwonConfiguration;
import ru.noties.markwon.MarkwonSpansFactory;
import ru.noties.markwon.MarkwonSpansFactoryImpl;
import ru.noties.markwon.MarkwonVisitor;
import ru.noties.markwon.MarkwonVisitorImpl;
import ru.noties.markwon.core.CorePlugin;
import ru.noties.markwon.core.MarkwonTheme;
import ru.noties.markwon.html.MarkwonHtmlRenderer;
import ru.noties.markwon.image.AsyncDrawableLoader;
import ru.noties.markwon.priority.PriorityProcessor;

class MarkwonBuilderImpl implements Markwon.Builder {
    private TextView.BufferType bufferType = TextView.BufferType.SPANNABLE;
    private final Context context;
    private final List<MarkwonPlugin> plugins = new ArrayList(3);
    private PriorityProcessor priorityProcessor;

    MarkwonBuilderImpl(Context context2) {
        this.context = context2;
    }

    public Markwon.Builder bufferType(TextView.BufferType bufferType2) {
        this.bufferType = bufferType2;
        return this;
    }

    public Markwon.Builder usePlugin(MarkwonPlugin plugin) {
        this.plugins.add(plugin);
        return this;
    }

    public Markwon.Builder usePlugins(Iterable<? extends MarkwonPlugin> plugins2) {
        for (MarkwonPlugin plugin : plugins2) {
            if (plugin != null) {
                this.plugins.add(plugin);
            } else {
                throw new NullPointerException();
            }
        }
        return this;
    }

    public MarkwonBuilderImpl priorityProcessor(PriorityProcessor priorityProcessor2) {
        this.priorityProcessor = priorityProcessor2;
        return this;
    }

    public Markwon build() {
        if (!this.plugins.isEmpty()) {
            PriorityProcessor priorityProcessor2 = this.priorityProcessor;
            if (priorityProcessor2 == null) {
                PriorityProcessor create = PriorityProcessor.create();
                this.priorityProcessor = create;
                priorityProcessor2 = create;
            }
            List<MarkwonPlugin> plugins2 = preparePlugins(priorityProcessor2, this.plugins);
            Parser.Builder parserBuilder = new Parser.Builder();
            MarkwonTheme.Builder themeBuilder = MarkwonTheme.builderWithDefaults(this.context);
            AsyncDrawableLoader.Builder asyncDrawableLoaderBuilder = new AsyncDrawableLoader.Builder();
            MarkwonConfiguration.Builder configurationBuilder = new MarkwonConfiguration.Builder();
            MarkwonVisitor.Builder visitorBuilder = new MarkwonVisitorImpl.BuilderImpl();
            MarkwonSpansFactory.Builder spanFactoryBuilder = new MarkwonSpansFactoryImpl.BuilderImpl();
            MarkwonHtmlRenderer.Builder htmlRendererBuilder = MarkwonHtmlRenderer.builder();
            for (MarkwonPlugin plugin : plugins2) {
                plugin.configureParser(parserBuilder);
                plugin.configureTheme(themeBuilder);
                plugin.configureImages(asyncDrawableLoaderBuilder);
                plugin.configureConfiguration(configurationBuilder);
                plugin.configureVisitor(visitorBuilder);
                plugin.configureSpansFactory(spanFactoryBuilder);
                plugin.configureHtmlRenderer(htmlRendererBuilder);
            }
            return new MarkwonImpl(this.bufferType, parserBuilder.build(), visitorBuilder.build(configurationBuilder.build(themeBuilder.build(), asyncDrawableLoaderBuilder.build(), htmlRendererBuilder.build(), spanFactoryBuilder.build()), new RenderPropsImpl()), Collections.unmodifiableList(plugins2));
        }
        throw new IllegalStateException("No plugins were added to this builder. Use #usePlugin method to add them");
    }

    static List<MarkwonPlugin> preparePlugins(PriorityProcessor priorityProcessor2, List<MarkwonPlugin> plugins2) {
        return priorityProcessor2.process(ensureImplicitCoreIfHasDependents(plugins2));
    }

    static List<MarkwonPlugin> ensureImplicitCoreIfHasDependents(List<MarkwonPlugin> plugins2) {
        boolean hasCore = false;
        boolean hasCoreDependents = false;
        Iterator<MarkwonPlugin> it = plugins2.iterator();
        while (true) {
            if (!it.hasNext()) {
                break;
            }
            MarkwonPlugin plugin = it.next();
            if (CorePlugin.class.isAssignableFrom(plugin.getClass())) {
                hasCore = true;
                break;
            } else if (!hasCoreDependents && plugin.priority().after().contains(CorePlugin.class)) {
                hasCoreDependents = true;
            }
        }
        if (!hasCoreDependents || hasCore) {
            return plugins2;
        }
        List<MarkwonPlugin> out = new ArrayList<>(plugins2.size() + 1);
        out.add(CorePlugin.create());
        out.addAll(plugins2);
        return out;
    }
}
