package ru.noties.markwon;

import ru.noties.markwon.core.MarkwonTheme;
import ru.noties.markwon.core.spans.LinkSpan;
import ru.noties.markwon.html.MarkwonHtmlParser;
import ru.noties.markwon.html.MarkwonHtmlRenderer;
import ru.noties.markwon.image.AsyncDrawableLoader;
import ru.noties.markwon.image.ImageSizeResolver;
import ru.noties.markwon.image.ImageSizeResolverDef;
import ru.noties.markwon.syntax.SyntaxHighlight;
import ru.noties.markwon.syntax.SyntaxHighlightNoOp;
import ru.noties.markwon.urlprocessor.UrlProcessor;
import ru.noties.markwon.urlprocessor.UrlProcessorNoOp;

public class MarkwonConfiguration {
    private final AsyncDrawableLoader asyncDrawableLoader;
    private final MarkwonHtmlParser htmlParser;
    private final MarkwonHtmlRenderer htmlRenderer;
    private final ImageSizeResolver imageSizeResolver;
    private final LinkSpan.Resolver linkResolver;
    private final MarkwonSpansFactory spansFactory;
    private final SyntaxHighlight syntaxHighlight;
    private final MarkwonTheme theme;
    private final UrlProcessor urlProcessor;

    public static Builder builder() {
        return new Builder();
    }

    private MarkwonConfiguration(Builder builder) {
        this.theme = builder.theme;
        this.asyncDrawableLoader = builder.asyncDrawableLoader;
        this.syntaxHighlight = builder.syntaxHighlight;
        this.linkResolver = builder.linkResolver;
        this.urlProcessor = builder.urlProcessor;
        this.imageSizeResolver = builder.imageSizeResolver;
        this.spansFactory = builder.spansFactory;
        this.htmlParser = builder.htmlParser;
        this.htmlRenderer = builder.htmlRenderer;
    }

    public MarkwonTheme theme() {
        return this.theme;
    }

    public AsyncDrawableLoader asyncDrawableLoader() {
        return this.asyncDrawableLoader;
    }

    public SyntaxHighlight syntaxHighlight() {
        return this.syntaxHighlight;
    }

    public LinkSpan.Resolver linkResolver() {
        return this.linkResolver;
    }

    public UrlProcessor urlProcessor() {
        return this.urlProcessor;
    }

    public ImageSizeResolver imageSizeResolver() {
        return this.imageSizeResolver;
    }

    public MarkwonHtmlParser htmlParser() {
        return this.htmlParser;
    }

    public MarkwonHtmlRenderer htmlRenderer() {
        return this.htmlRenderer;
    }

    public MarkwonSpansFactory spansFactory() {
        return this.spansFactory;
    }

    public static class Builder {
        /* access modifiers changed from: private */
        public AsyncDrawableLoader asyncDrawableLoader;
        /* access modifiers changed from: private */
        public MarkwonHtmlParser htmlParser;
        /* access modifiers changed from: private */
        public MarkwonHtmlRenderer htmlRenderer;
        /* access modifiers changed from: private */
        public ImageSizeResolver imageSizeResolver;
        /* access modifiers changed from: private */
        public LinkSpan.Resolver linkResolver;
        /* access modifiers changed from: private */
        public MarkwonSpansFactory spansFactory;
        /* access modifiers changed from: private */
        public SyntaxHighlight syntaxHighlight;
        /* access modifiers changed from: private */
        public MarkwonTheme theme;
        /* access modifiers changed from: private */
        public UrlProcessor urlProcessor;

        Builder() {
        }

        public Builder syntaxHighlight(SyntaxHighlight syntaxHighlight2) {
            this.syntaxHighlight = syntaxHighlight2;
            return this;
        }

        public Builder linkResolver(LinkSpan.Resolver linkResolver2) {
            this.linkResolver = linkResolver2;
            return this;
        }

        public Builder urlProcessor(UrlProcessor urlProcessor2) {
            this.urlProcessor = urlProcessor2;
            return this;
        }

        public Builder htmlParser(MarkwonHtmlParser htmlParser2) {
            this.htmlParser = htmlParser2;
            return this;
        }

        public Builder imageSizeResolver(ImageSizeResolver imageSizeResolver2) {
            this.imageSizeResolver = imageSizeResolver2;
            return this;
        }

        public MarkwonConfiguration build(MarkwonTheme theme2, AsyncDrawableLoader asyncDrawableLoader2, MarkwonHtmlRenderer htmlRenderer2, MarkwonSpansFactory spansFactory2) {
            this.theme = theme2;
            this.asyncDrawableLoader = asyncDrawableLoader2;
            this.htmlRenderer = htmlRenderer2;
            this.spansFactory = spansFactory2;
            if (this.syntaxHighlight == null) {
                this.syntaxHighlight = new SyntaxHighlightNoOp();
            }
            if (this.linkResolver == null) {
                this.linkResolver = new LinkResolverDef();
            }
            if (this.urlProcessor == null) {
                this.urlProcessor = new UrlProcessorNoOp();
            }
            if (this.imageSizeResolver == null) {
                this.imageSizeResolver = new ImageSizeResolverDef();
            }
            if (this.htmlParser == null) {
                this.htmlParser = MarkwonHtmlParser.noOp();
            }
            return new MarkwonConfiguration(this);
        }
    }
}
