package ru.noties.markwon;

import android.text.Spanned;
import android.widget.TextView;
import java.util.List;
import org.commonmark.node.Node;
import org.commonmark.parser.Parser;

class MarkwonImpl extends Markwon {
    private final TextView.BufferType bufferType;
    private final Parser parser;
    private final List<MarkwonPlugin> plugins;
    private final MarkwonVisitor visitor;

    MarkwonImpl(TextView.BufferType bufferType2, Parser parser2, MarkwonVisitor visitor2, List<MarkwonPlugin> plugins2) {
        this.bufferType = bufferType2;
        this.parser = parser2;
        this.visitor = visitor2;
        this.plugins = plugins2;
    }

    public Node parse(String input) {
        for (MarkwonPlugin plugin : this.plugins) {
            input = plugin.processMarkdown(input);
        }
        return this.parser.parse(input);
    }

    public Spanned render(Node node) {
        for (MarkwonPlugin plugin : this.plugins) {
            plugin.beforeRender(node);
        }
        node.accept(this.visitor);
        for (MarkwonPlugin plugin2 : this.plugins) {
            plugin2.afterRender(node, this.visitor);
        }
        Spanned spanned = this.visitor.builder().spannableStringBuilder();
        this.visitor.clear();
        return spanned;
    }

    public Spanned toMarkdown(String input) {
        return render(parse(input));
    }

    public void setMarkdown(TextView textView, String markdown) {
        setParsedMarkdown(textView, toMarkdown(markdown));
    }

    public void setParsedMarkdown(TextView textView, Spanned markdown) {
        for (MarkwonPlugin plugin : this.plugins) {
            plugin.beforeSetText(textView, markdown);
        }
        textView.setText(markdown, this.bufferType);
        for (MarkwonPlugin plugin2 : this.plugins) {
            plugin2.afterSetText(textView);
        }
    }

    public boolean hasPlugin(Class<? extends MarkwonPlugin> type) {
        return getPlugin(type) != null;
    }

    public <P extends MarkwonPlugin> P getPlugin(Class<P> type) {
        MarkwonPlugin out = null;
        for (MarkwonPlugin plugin : this.plugins) {
            if (type.isAssignableFrom(plugin.getClass())) {
                out = plugin;
            }
        }
        return out;
    }
}
