package ru.noties.markwon;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import java.util.HashMap;
import java.util.Map;
import org.commonmark.node.Node;

public abstract class MarkwonNodeRenderer {

    public interface ViewProvider<N extends Node> {
        View provide(LayoutInflater layoutInflater, ViewGroup viewGroup, Markwon markwon, N n);
    }

    public abstract void render(ViewGroup viewGroup, Markwon markwon, String str);

    public abstract void render(ViewGroup viewGroup, Markwon markwon, Node node);

    public static Builder builder(ViewProvider<Node> defaultViewProvider) {
        return new Builder(defaultViewProvider);
    }

    public static Builder builder(int defaultViewProviderLayoutResId, int defaultViewProviderTextViewId) {
        return new Builder(new SimpleTextViewProvider(defaultViewProviderLayoutResId, defaultViewProviderTextViewId));
    }

    public static class Builder {
        /* access modifiers changed from: private */
        public final ViewProvider<Node> defaultViewProvider;
        /* access modifiers changed from: private */
        public LayoutInflater inflater;
        /* access modifiers changed from: private */
        public MarkwonReducer reducer;
        /* access modifiers changed from: private */
        public Map<Class<? extends Node>, ViewProvider<Node>> viewProviders = new HashMap(3);

        public Builder(ViewProvider<Node> defaultViewProvider2) {
            this.defaultViewProvider = defaultViewProvider2;
        }

        public Builder reducer(MarkwonReducer reducer2) {
            this.reducer = reducer2;
            return this;
        }

        public <N extends Node> Builder viewProvider(Class<N> type, ViewProvider<? super N> viewProvider) {
            this.viewProviders.put(type, viewProvider);
            return this;
        }

        public Builder inflater(LayoutInflater inflater2) {
            this.inflater = inflater2;
            return this;
        }

        public MarkwonNodeRenderer build() {
            if (this.reducer == null) {
                this.reducer = MarkwonReducer.directChildren();
            }
            return new Impl(this);
        }
    }

    public static class SimpleTextViewProvider implements ViewProvider<Node> {
        private final int layoutResId;
        private final int textViewId;

        public SimpleTextViewProvider(int layoutResId2, int textViewId2) {
            this.layoutResId = layoutResId2;
            this.textViewId = textViewId2;
        }

        public View provide(LayoutInflater inflater, ViewGroup group, Markwon markwon, Node node) {
            View view = inflater.inflate(this.layoutResId, group, false);
            markwon.setParsedMarkdown((TextView) view.findViewById(this.textViewId), markwon.render(node));
            return view;
        }
    }

    static class Impl extends MarkwonNodeRenderer {
        private final ViewProvider<Node> defaultViewProvider;
        private LayoutInflater inflater;
        private final MarkwonReducer reducer;
        private final Map<Class<? extends Node>, ViewProvider<Node>> viewProviders;

        Impl(Builder builder) {
            this.reducer = builder.reducer;
            this.viewProviders = builder.viewProviders;
            this.defaultViewProvider = builder.defaultViewProvider;
            this.inflater = builder.inflater;
        }

        public void render(ViewGroup group, Markwon markwon, String markdown) {
            render(group, markwon, markwon.parse(markdown));
        }

        public void render(ViewGroup group, Markwon markwon, Node root) {
            LayoutInflater inflater2 = ensureLayoutInflater(group.getContext());
            for (Node node : this.reducer.reduce(root)) {
                group.addView(viewProvider(node).provide(inflater2, group, markwon, node));
            }
        }

        private LayoutInflater ensureLayoutInflater(Context context) {
            LayoutInflater inflater2 = this.inflater;
            if (inflater2 != null) {
                return inflater2;
            }
            LayoutInflater inflater3 = LayoutInflater.from(context);
            this.inflater = inflater3;
            return inflater3;
        }

        private ViewProvider<Node> viewProvider(Node node) {
            ViewProvider<Node> provider = this.viewProviders.get(node.getClass());
            if (provider != null) {
                return provider;
            }
            return this.defaultViewProvider;
        }
    }
}
