package ru.noties.markwon;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import org.commonmark.node.Node;
import ru.noties.markwon.MarkwonSpansFactory;

class MarkwonSpansFactoryImpl implements MarkwonSpansFactory {
    private final Map<Class<? extends Node>, SpanFactory> factories;

    MarkwonSpansFactoryImpl(Map<Class<? extends Node>, SpanFactory> factories2) {
        this.factories = factories2;
    }

    public <N extends Node> SpanFactory get(Class<N> node) {
        return this.factories.get(node);
    }

    public <N extends Node> SpanFactory require(Class<N> node) {
        SpanFactory f = get(node);
        if (f != null) {
            return f;
        }
        throw new NullPointerException(node.getName());
    }

    static class BuilderImpl implements MarkwonSpansFactory.Builder {
        private final Map<Class<? extends Node>, SpanFactory> factories = new HashMap(3);

        BuilderImpl() {
        }

        public <N extends Node> MarkwonSpansFactory.Builder setFactory(Class<N> node, SpanFactory factory) {
            if (factory == null) {
                this.factories.remove(node);
            } else {
                this.factories.put(node, factory);
            }
            return this;
        }

        public <N extends Node> SpanFactory getFactory(Class<N> node) {
            return this.factories.get(node);
        }

        public MarkwonSpansFactory build() {
            return new MarkwonSpansFactoryImpl(Collections.unmodifiableMap(this.factories));
        }
    }
}
