package ru.noties.markwon.core.spans;

import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.RectF;
import android.text.Layout;
import android.text.style.LeadingMarginSpan;
import ru.noties.markwon.core.MarkwonTheme;
import ru.noties.markwon.utils.LeadingMarginUtils;

public class BulletListItemSpan implements LeadingMarginSpan {
    private final RectF circle = ObjectsPool.rectF();
    private final int level;
    private final Paint paint = ObjectsPool.paint();
    private final Rect rectangle = ObjectsPool.rect();
    private MarkwonTheme theme;

    public BulletListItemSpan(MarkwonTheme theme2, int level2) {
        this.theme = theme2;
        this.level = level2;
    }

    public int getLeadingMargin(boolean first) {
        return this.theme.getBlockMargin();
    }

    public void drawLeadingMargin(Canvas c, Paint p, int x, int dir, int top, int baseline, int bottom, CharSequence text, int start, int end, boolean first, Layout layout) {
        int diff;
        Canvas canvas = c;
        if (first) {
            if (LeadingMarginUtils.selfStart(start, text, this)) {
                this.paint.set(p);
                this.theme.applyListItemStyle(this.paint);
                int save = c.save();
                try {
                    int width = this.theme.getBlockMargin();
                    int side = this.theme.getBulletWidth((int) ((this.paint.descent() - this.paint.ascent()) + 0.5f));
                    int marginLeft = (width - side) / 2;
                    if (dir < 0) {
                        diff = x - (layout.getWidth() - (this.level * width));
                    } else {
                        diff = (this.level * width) - x;
                    }
                    int left = x + (dir * marginLeft);
                    int right = (dir * side) + left;
                    int l = Math.min(left, right) + (dir * diff);
                    int r = Math.max(left, right) + (dir * diff);
                    int t = (baseline + ((int) (((this.paint.descent() + this.paint.ascent()) / 2.0f) + 0.5f))) - (side / 2);
                    int b = t + side;
                    int i = this.level;
                    if (i != 0) {
                        int i2 = width;
                        if (i != 1) {
                            this.rectangle.set(l, t, r, b);
                            this.paint.setStyle(Paint.Style.FILL);
                            canvas.drawRect(this.rectangle, this.paint);
                        }
                    }
                    this.circle.set((float) l, (float) t, (float) r, (float) b);
                    this.paint.setStyle(this.level == 0 ? Paint.Style.FILL : Paint.Style.STROKE);
                    canvas.drawOval(this.circle, this.paint);
                } finally {
                    canvas.restoreToCount(save);
                }
            }
        }
    }
}
