package ru.noties.markwon.html;

import android.text.TextUtils;
import java.util.Iterator;
import java.util.NoSuchElementException;

public abstract class CssInlineStyleParser {
    public abstract Iterable<CssProperty> parse(String str);

    public static CssInlineStyleParser create() {
        return new Impl();
    }

    static class Impl extends CssInlineStyleParser {
        Impl() {
        }

        public Iterable<CssProperty> parse(String inlineStyle) {
            return new CssIterable(inlineStyle);
        }

        private static class CssIterable implements Iterable<CssProperty> {
            /* access modifiers changed from: private */
            public final String input;

            CssIterable(String input2) {
                this.input = input2;
            }

            public Iterator<CssProperty> iterator() {
                return new CssIterator();
            }

            private class CssIterator implements Iterator<CssProperty> {
                private final StringBuilder builder;
                private final CssProperty cssProperty;
                private int index;
                private final int length;

                private CssIterator() {
                    this.cssProperty = new CssProperty();
                    this.builder = new StringBuilder();
                    this.length = CssIterable.this.input.length();
                }

                public boolean hasNext() {
                    prepareNext();
                    return hasNextPrepared();
                }

                public CssProperty next() {
                    if (hasNextPrepared()) {
                        return this.cssProperty;
                    }
                    throw new NoSuchElementException();
                }

                private void prepareNext() {
                    this.cssProperty.set("", "");
                    this.builder.setLength(0);
                    String key = null;
                    String value = null;
                    boolean keyHasWhiteSpace = false;
                    for (int i = this.index; i < this.length; i++) {
                        char c = CssIterable.this.input.charAt(i);
                        if (key == null) {
                            if (':' == c) {
                                if (this.builder.length() > 0) {
                                    key = this.builder.toString().trim();
                                }
                                this.builder.setLength(0);
                            } else if (';' == c) {
                                this.builder.setLength(0);
                            } else if (Character.isWhitespace(c)) {
                                if (this.builder.length() > 0) {
                                    keyHasWhiteSpace = true;
                                }
                            } else if (keyHasWhiteSpace) {
                                this.builder.setLength(0);
                                this.builder.append(c);
                                keyHasWhiteSpace = false;
                            } else {
                                this.builder.append(c);
                            }
                        } else if (value != null) {
                            continue;
                        } else if (Character.isWhitespace(c)) {
                            if (this.builder.length() > 0) {
                                this.builder.append(c);
                            }
                        } else if (';' == c) {
                            value = this.builder.toString().trim();
                            this.builder.setLength(0);
                            if (hasValues(key, value)) {
                                this.index = i + 1;
                                this.cssProperty.set(key, value);
                                return;
                            }
                        } else {
                            this.builder.append(c);
                        }
                    }
                    if (key != null && this.builder.length() > 0) {
                        this.cssProperty.set(key, this.builder.toString().trim());
                        this.index = this.length;
                    }
                }

                private boolean hasNextPrepared() {
                    return hasValues(this.cssProperty.key(), this.cssProperty.value());
                }

                private boolean hasValues(String key, String value) {
                    return !TextUtils.isEmpty(key) && !TextUtils.isEmpty(value);
                }
            }
        }
    }
}
