package ru.noties.markwon.html;

import java.util.Arrays;
import java.util.Collection;
import org.commonmark.node.HtmlBlock;
import org.commonmark.node.HtmlInline;
import org.commonmark.node.Node;
import ru.noties.markwon.AbstractMarkwonPlugin;
import ru.noties.markwon.MarkwonConfiguration;
import ru.noties.markwon.MarkwonVisitor;
import ru.noties.markwon.html.MarkwonHtmlRenderer;
import ru.noties.markwon.html.tag.BlockquoteHandler;
import ru.noties.markwon.html.tag.EmphasisHandler;
import ru.noties.markwon.html.tag.HeadingHandler;
import ru.noties.markwon.html.tag.ImageHandler;
import ru.noties.markwon.html.tag.LinkHandler;
import ru.noties.markwon.html.tag.ListHandler;
import ru.noties.markwon.html.tag.StrikeHandler;
import ru.noties.markwon.html.tag.StrongEmphasisHandler;
import ru.noties.markwon.html.tag.SubScriptHandler;
import ru.noties.markwon.html.tag.SuperScriptHandler;
import ru.noties.markwon.html.tag.UnderlineHandler;

public class HtmlPlugin extends AbstractMarkwonPlugin {
    public static final float SCRIPT_DEF_TEXT_SIZE_RATIO = 0.75f;

    public static HtmlPlugin create() {
        return new HtmlPlugin();
    }

    public void configureConfiguration(MarkwonConfiguration.Builder builder) {
        builder.htmlParser(MarkwonHtmlParserImpl.create());
    }

    public void configureHtmlRenderer(MarkwonHtmlRenderer.Builder builder) {
        builder.setHandler("img", (TagHandler) ImageHandler.create()).setHandler("a", (TagHandler) new LinkHandler()).setHandler("blockquote", (TagHandler) new BlockquoteHandler()).setHandler("sub", (TagHandler) new SubScriptHandler()).setHandler("sup", (TagHandler) new SuperScriptHandler()).setHandler((Collection<String>) Arrays.asList(new String[]{"b", "strong"}), (TagHandler) new StrongEmphasisHandler()).setHandler((Collection<String>) Arrays.asList(new String[]{"s", "del"}), (TagHandler) new StrikeHandler()).setHandler((Collection<String>) Arrays.asList(new String[]{"u", "ins"}), (TagHandler) new UnderlineHandler()).setHandler((Collection<String>) Arrays.asList(new String[]{"ul", "ol"}), (TagHandler) new ListHandler()).setHandler((Collection<String>) Arrays.asList(new String[]{"i", "em", "cite", "dfn"}), (TagHandler) new EmphasisHandler()).setHandler((Collection<String>) Arrays.asList(new String[]{"h1", "h2", "h3", "h4", "h5", "h6"}), (TagHandler) new HeadingHandler());
    }

    public void afterRender(Node node, MarkwonVisitor visitor) {
        MarkwonConfiguration configuration = visitor.configuration();
        configuration.htmlRenderer().render(visitor, configuration.htmlParser());
    }

    public void configureVisitor(MarkwonVisitor.Builder builder) {
        builder.on(HtmlBlock.class, new MarkwonVisitor.NodeVisitor<HtmlBlock>() {
            public void visit(MarkwonVisitor visitor, HtmlBlock htmlBlock) {
                HtmlPlugin.this.visitHtml(visitor, htmlBlock.getLiteral());
            }
        }).on(HtmlInline.class, new MarkwonVisitor.NodeVisitor<HtmlInline>() {
            public void visit(MarkwonVisitor visitor, HtmlInline htmlInline) {
                HtmlPlugin.this.visitHtml(visitor, htmlInline.getLiteral());
            }
        });
    }

    /* access modifiers changed from: private */
    public void visitHtml(MarkwonVisitor visitor, String html) {
        if (html != null) {
            visitor.configuration().htmlParser().processFragment(visitor.builder(), html);
        }
    }
}
