package ru.noties.markwon.html;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import ru.noties.markwon.html.HtmlTag;

abstract class HtmlTagImpl implements HtmlTag {
    final Map<String, String> attributes;
    int end = -1;
    final String name;
    final int start;

    /* access modifiers changed from: package-private */
    public abstract void closeAt(int i);

    protected HtmlTagImpl(String name2, int start2, Map<String, String> attributes2) {
        this.name = name2;
        this.start = start2;
        this.attributes = attributes2;
    }

    public String name() {
        return this.name;
    }

    public int start() {
        return this.start;
    }

    public int end() {
        return this.end;
    }

    public boolean isEmpty() {
        return this.start == this.end;
    }

    public Map<String, String> attributes() {
        return this.attributes;
    }

    public boolean isClosed() {
        return this.end > -1;
    }

    static class InlineImpl extends HtmlTagImpl implements HtmlTag.Inline {
        InlineImpl(String name, int start, Map<String, String> attributes) {
            super(name, start, attributes);
        }

        /* access modifiers changed from: package-private */
        public void closeAt(int end) {
            if (!isClosed()) {
                this.end = end;
            }
        }

        public String toString() {
            return "InlineImpl{name='" + this.name + '\'' + ", start=" + this.start + ", end=" + this.end + ", attributes=" + this.attributes + '}';
        }

        public boolean isInline() {
            return true;
        }

        public boolean isBlock() {
            return false;
        }

        public HtmlTag.Inline getAsInline() {
            return this;
        }

        public HtmlTag.Block getAsBlock() {
            throw new ClassCastException("Cannot cast Inline instance to Block");
        }
    }

    static class BlockImpl extends HtmlTagImpl implements HtmlTag.Block {
        List<BlockImpl> children;
        final BlockImpl parent;

        static BlockImpl root() {
            return new BlockImpl("", 0, Collections.emptyMap(), (BlockImpl) null);
        }

        static BlockImpl create(String name, int start, Map<String, String> attributes, BlockImpl parent2) {
            return new BlockImpl(name, start, attributes, parent2);
        }

        BlockImpl(String name, int start, Map<String, String> attributes, BlockImpl parent2) {
            super(name, start, attributes);
            this.parent = parent2;
        }

        /* access modifiers changed from: package-private */
        public void closeAt(int end) {
            if (!isClosed()) {
                this.end = end;
                List<BlockImpl> list = this.children;
                if (list != null) {
                    for (BlockImpl child : list) {
                        child.closeAt(end);
                    }
                }
            }
        }

        public boolean isRoot() {
            return this.parent == null;
        }

        public HtmlTag.Block parent() {
            return this.parent;
        }

        public List<HtmlTag.Block> children() {
            List<BlockImpl> list = this.children;
            if (list == null) {
                return Collections.emptyList();
            }
            return Collections.unmodifiableList(list);
        }

        public Map<String, String> attributes() {
            return this.attributes;
        }

        public boolean isInline() {
            return false;
        }

        public boolean isBlock() {
            return true;
        }

        public HtmlTag.Inline getAsInline() {
            throw new ClassCastException("Cannot cast Block instance to Inline");
        }

        public HtmlTag.Block getAsBlock() {
            return this;
        }

        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append("BlockImpl{name='");
            sb.append(this.name);
            sb.append('\'');
            sb.append(", start=");
            sb.append(this.start);
            sb.append(", end=");
            sb.append(this.end);
            sb.append(", attributes=");
            sb.append(this.attributes);
            sb.append(", parent=");
            BlockImpl blockImpl = this.parent;
            sb.append(blockImpl != null ? blockImpl.name : null);
            sb.append(", children=");
            sb.append(this.children);
            sb.append('}');
            return sb.toString();
        }
    }
}
