package ru.noties.markwon.html;

import com.google.firebase.messaging.Constants;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Set;
import ru.noties.markwon.html.HtmlTag;
import ru.noties.markwon.html.HtmlTagImpl;
import ru.noties.markwon.html.MarkwonHtmlParser;
import ru.noties.markwon.html.jsoup.nodes.Attribute;
import ru.noties.markwon.html.jsoup.nodes.Attributes;
import ru.noties.markwon.html.jsoup.parser.CharacterReader;
import ru.noties.markwon.html.jsoup.parser.ParseErrorList;
import ru.noties.markwon.html.jsoup.parser.Token;
import ru.noties.markwon.html.jsoup.parser.Tokeniser;

public class MarkwonHtmlParserImpl extends MarkwonHtmlParser {
    private static final Set<String> BLOCK_TAGS = Collections.unmodifiableSet(new HashSet(Arrays.asList(new String[]{"address", "article", "aside", "blockquote", "canvas", "dd", "div", "dl", "dt", "fieldset", "figcaption", "figure", "footer", "form", "h1", "h2", "h3", "h4", "h5", "h6", "header", "hgroup", "hr", TAG_LIST_ITEM, "main", "nav", "noscript", "ol", "output", TAG_PARAGRAPH, "pre", "section", "table", "tfoot", "ul", "video"})));
    static final Set<String> INLINE_TAGS = Collections.unmodifiableSet(new HashSet(Arrays.asList(new String[]{"a", "abbr", "acronym", "b", "bdo", "big", "br", "button", "cite", "code", "dfn", "em", "i", "img", "input", "kbd", Constants.ScionAnalytics.PARAM_LABEL, "map", "object", "q", "samp", "script", "select", "small", "span", "strong", "sub", "sup", "textarea", "time", "tt", "var"})));
    private static final String TAG_LIST_ITEM = "li";
    private static final String TAG_PARAGRAPH = "p";
    private static final Set<String> VOID_TAGS = Collections.unmodifiableSet(new HashSet(Arrays.asList(new String[]{"area", "base", "br", "col", "embed", "hr", "img", "input", "keygen", "link", "meta", "param", Constants.ScionAnalytics.PARAM_SOURCE, "track", "wbr"})));
    private HtmlTagImpl.BlockImpl currentBlock = HtmlTagImpl.BlockImpl.root();
    private final HtmlEmptyTagReplacement emptyTagReplacement;
    private final List<HtmlTagImpl.InlineImpl> inlineTags = new ArrayList(0);
    private boolean isInsidePreTag;
    private boolean previousIsBlock;
    private final TrimmingAppender trimmingAppender;

    public static MarkwonHtmlParserImpl create() {
        return create(HtmlEmptyTagReplacement.create());
    }

    public static MarkwonHtmlParserImpl create(HtmlEmptyTagReplacement inlineTagReplacement) {
        return new MarkwonHtmlParserImpl(inlineTagReplacement, TrimmingAppender.create());
    }

    MarkwonHtmlParserImpl(HtmlEmptyTagReplacement replacement, TrimmingAppender trimmingAppender2) {
        this.emptyTagReplacement = replacement;
        this.trimmingAppender = trimmingAppender2;
    }

    public <T extends Appendable & CharSequence> void processFragment(T output, String htmlFragment) {
        Tokeniser tokeniser = new Tokeniser(new CharacterReader(htmlFragment), ParseErrorList.noTracking());
        while (true) {
            Token token = tokeniser.read();
            Token.TokenType tokenType = token.type;
            if (Token.TokenType.EOF != tokenType) {
                switch (AnonymousClass1.$SwitchMap$ru$noties$markwon$html$jsoup$parser$Token$TokenType[tokenType.ordinal()]) {
                    case 1:
                        Token.StartTag startTag = (Token.StartTag) token;
                        if (!isInlineTag(startTag.normalName)) {
                            processBlockTagStart(output, startTag);
                            break;
                        } else {
                            processInlineTagStart(output, startTag);
                            break;
                        }
                    case 2:
                        Token.EndTag endTag = (Token.EndTag) token;
                        if (!isInlineTag(endTag.normalName)) {
                            processBlockTagEnd(output, endTag);
                            break;
                        } else {
                            processInlineTagEnd(output, endTag);
                            break;
                        }
                    case 3:
                        processCharacter(output, (Token.Character) token);
                        break;
                }
                token.reset();
            } else {
                return;
            }
        }
    }

    /* renamed from: ru.noties.markwon.html.MarkwonHtmlParserImpl$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$ru$noties$markwon$html$jsoup$parser$Token$TokenType;

        static {
            int[] iArr = new int[Token.TokenType.values().length];
            $SwitchMap$ru$noties$markwon$html$jsoup$parser$Token$TokenType = iArr;
            try {
                iArr[Token.TokenType.StartTag.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$ru$noties$markwon$html$jsoup$parser$Token$TokenType[Token.TokenType.EndTag.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$ru$noties$markwon$html$jsoup$parser$Token$TokenType[Token.TokenType.Character.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
        }
    }

    public void flushInlineTags(int documentLength, MarkwonHtmlParser.FlushAction<HtmlTag.Inline> action) {
        if (this.inlineTags.size() > 0) {
            if (documentLength > -1) {
                for (HtmlTagImpl.InlineImpl inline : this.inlineTags) {
                    inline.closeAt(documentLength);
                }
            }
            action.apply(Collections.unmodifiableList(this.inlineTags));
            this.inlineTags.clear();
            return;
        }
        action.apply(Collections.emptyList());
    }

    public void flushBlockTags(int documentLength, MarkwonHtmlParser.FlushAction<HtmlTag.Block> action) {
        HtmlTagImpl.BlockImpl block = this.currentBlock;
        while (block.parent != null) {
            block = block.parent;
        }
        if (documentLength > -1) {
            block.closeAt(documentLength);
        }
        List<HtmlTag.Block> children = block.children();
        if (children.size() > 0) {
            action.apply(children);
        } else {
            action.apply(Collections.emptyList());
        }
        this.currentBlock = HtmlTagImpl.BlockImpl.root();
    }

    public void reset() {
        this.inlineTags.clear();
        this.currentBlock = HtmlTagImpl.BlockImpl.root();
    }

    /* access modifiers changed from: protected */
    public <T extends Appendable & CharSequence> void processInlineTagStart(T output, Token.StartTag startTag) {
        String name = startTag.normalName;
        HtmlTagImpl.InlineImpl inline = new HtmlTagImpl.InlineImpl(name, ((CharSequence) output).length(), extractAttributes(startTag));
        ensureNewLineIfPreviousWasBlock(output);
        if (isVoidTag(name) || startTag.selfClosing) {
            String replacement = this.emptyTagReplacement.replace(inline);
            if (replacement != null && replacement.length() > 0) {
                AppendableUtils.appendQuietly((Appendable) output, (CharSequence) replacement);
            }
            inline.closeAt(((CharSequence) output).length());
        }
        this.inlineTags.add(inline);
    }

    /* access modifiers changed from: protected */
    public <T extends Appendable & CharSequence> void processInlineTagEnd(T output, Token.EndTag endTag) {
        HtmlTagImpl.InlineImpl openInline = findOpenInlineTag(endTag.normalName);
        if (openInline != null) {
            if (isEmpty(output, openInline)) {
                appendEmptyTagReplacement(output, openInline);
            }
            openInline.closeAt(((CharSequence) output).length());
        }
    }

    /* access modifiers changed from: protected */
    public <T extends Appendable & CharSequence> void processBlockTagStart(T output, Token.StartTag startTag) {
        String name = startTag.normalName;
        if (TAG_PARAGRAPH.equals(this.currentBlock.name)) {
            this.currentBlock.closeAt(((CharSequence) output).length());
            AppendableUtils.appendQuietly((Appendable) output, 10);
            this.currentBlock = this.currentBlock.parent;
        } else if (TAG_LIST_ITEM.equals(name) && TAG_LIST_ITEM.equals(this.currentBlock.name)) {
            this.currentBlock.closeAt(((CharSequence) output).length());
            this.currentBlock = this.currentBlock.parent;
        }
        if (isBlockTag(name)) {
            this.isInsidePreTag = "pre".equals(name);
            ensureNewLine(output);
        } else {
            ensureNewLineIfPreviousWasBlock(output);
        }
        HtmlTagImpl.BlockImpl block = HtmlTagImpl.BlockImpl.create(name, ((CharSequence) output).length(), extractAttributes(startTag), this.currentBlock);
        boolean isVoid = isVoidTag(name) || startTag.selfClosing;
        if (isVoid) {
            String replacement = this.emptyTagReplacement.replace(block);
            if (replacement != null && replacement.length() > 0) {
                AppendableUtils.appendQuietly((Appendable) output, (CharSequence) replacement);
            }
            block.closeAt(((CharSequence) output).length());
        }
        appendBlockChild(block.parent, block);
        if (!isVoid) {
            this.currentBlock = block;
        }
    }

    /* access modifiers changed from: protected */
    public <T extends Appendable & CharSequence> void processBlockTagEnd(T output, Token.EndTag endTag) {
        String name = endTag.normalName;
        HtmlTagImpl.BlockImpl block = findOpenBlockTag(endTag.normalName);
        if (block != null) {
            if ("pre".equals(name)) {
                this.isInsidePreTag = false;
            }
            if (isEmpty(output, block)) {
                appendEmptyTagReplacement(output, block);
            }
            block.closeAt(((CharSequence) output).length());
            if (!block.isEmpty()) {
                this.previousIsBlock = isBlockTag(block.name);
            }
            if (TAG_PARAGRAPH.equals(name)) {
                AppendableUtils.appendQuietly((Appendable) output, 10);
            }
            this.currentBlock = block.parent;
        }
    }

    /* access modifiers changed from: protected */
    public <T extends Appendable & CharSequence> void processCharacter(T output, Token.Character character) {
        if (this.isInsidePreTag) {
            AppendableUtils.appendQuietly((Appendable) output, (CharSequence) character.getData());
            return;
        }
        ensureNewLineIfPreviousWasBlock(output);
        this.trimmingAppender.append(output, character.getData());
    }

    /* access modifiers changed from: protected */
    public void appendBlockChild(HtmlTagImpl.BlockImpl parent, HtmlTagImpl.BlockImpl child) {
        List<HtmlTagImpl.BlockImpl> children = parent.children;
        if (children == null) {
            children = new ArrayList<>(2);
            parent.children = children;
        }
        children.add(child);
    }

    /* access modifiers changed from: protected */
    public HtmlTagImpl.InlineImpl findOpenInlineTag(String name) {
        int i = this.inlineTags.size();
        while (true) {
            i--;
            if (i <= -1) {
                return null;
            }
            HtmlTagImpl.InlineImpl inline = this.inlineTags.get(i);
            if (name.equals(inline.name) && inline.end < 0) {
                return inline;
            }
        }
    }

    /* access modifiers changed from: protected */
    public HtmlTagImpl.BlockImpl findOpenBlockTag(String name) {
        HtmlTagImpl.BlockImpl blockTag = this.currentBlock;
        while (blockTag != null && !name.equals(blockTag.name) && !blockTag.isClosed()) {
            blockTag = blockTag.parent;
        }
        return blockTag;
    }

    /* access modifiers changed from: protected */
    public <T extends Appendable & CharSequence> void ensureNewLineIfPreviousWasBlock(T output) {
        if (this.previousIsBlock) {
            ensureNewLine(output);
            this.previousIsBlock = false;
        }
    }

    protected static boolean isInlineTag(String name) {
        return INLINE_TAGS.contains(name);
    }

    protected static boolean isVoidTag(String name) {
        return VOID_TAGS.contains(name);
    }

    protected static boolean isBlockTag(String name) {
        return BLOCK_TAGS.contains(name);
    }

    protected static <T extends Appendable & CharSequence> void ensureNewLine(T output) {
        int length = ((CharSequence) output).length();
        if (length > 0 && 10 != ((CharSequence) output).charAt(length - 1)) {
            AppendableUtils.appendQuietly((Appendable) output, 10);
        }
    }

    protected static Map<String, String> extractAttributes(Token.StartTag startTag) {
        Attributes attributes = startTag.attributes;
        int size = attributes.size();
        if (size <= 0) {
            return Collections.emptyMap();
        }
        Map<String, String> map = new HashMap<>(size);
        Iterator<Attribute> it = attributes.iterator();
        while (it.hasNext()) {
            Attribute attribute = it.next();
            map.put(attribute.getKey().toLowerCase(Locale.US), attribute.getValue());
        }
        return Collections.unmodifiableMap(map);
    }

    protected static <T extends Appendable & CharSequence> boolean isEmpty(T output, HtmlTagImpl tag) {
        return tag.start == ((CharSequence) output).length();
    }

    /* access modifiers changed from: protected */
    public <T extends Appendable & CharSequence> void appendEmptyTagReplacement(T output, HtmlTagImpl tag) {
        String replacement = this.emptyTagReplacement.replace(tag);
        if (replacement != null) {
            AppendableUtils.appendQuietly((Appendable) output, (CharSequence) replacement);
        }
    }
}
