package ru.noties.markwon.html;

import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import ru.noties.markwon.MarkwonVisitor;
import ru.noties.markwon.html.HtmlTag;
import ru.noties.markwon.html.MarkwonHtmlParser;
import ru.noties.markwon.html.MarkwonHtmlRenderer;

class MarkwonHtmlRendererImpl extends MarkwonHtmlRenderer {
    private final boolean allowNonClosedTags;
    private final Map<String, TagHandler> tagHandlers;

    MarkwonHtmlRendererImpl(boolean allowNonClosedTags2, Map<String, TagHandler> tagHandlers2) {
        this.allowNonClosedTags = allowNonClosedTags2;
        this.tagHandlers = tagHandlers2;
    }

    public void render(final MarkwonVisitor visitor, MarkwonHtmlParser parser) {
        int end;
        if (!this.allowNonClosedTags) {
            end = -1;
        } else {
            end = visitor.length();
        }
        parser.flushInlineTags(end, new MarkwonHtmlParser.FlushAction<HtmlTag.Inline>() {
            public void apply(List<HtmlTag.Inline> tags) {
                TagHandler handler;
                for (HtmlTag.Inline inline : tags) {
                    if (inline.isClosed() && (handler = MarkwonHtmlRendererImpl.this.tagHandler(inline.name())) != null) {
                        handler.handle(visitor, MarkwonHtmlRendererImpl.this, inline);
                    }
                }
            }
        });
        parser.flushBlockTags(end, new MarkwonHtmlParser.FlushAction<HtmlTag.Block>() {
            public void apply(List<HtmlTag.Block> tags) {
                for (HtmlTag.Block block : tags) {
                    if (block.isClosed()) {
                        TagHandler handler = MarkwonHtmlRendererImpl.this.tagHandler(block.name());
                        if (handler != null) {
                            handler.handle(visitor, MarkwonHtmlRendererImpl.this, block);
                        } else {
                            apply(block.children());
                        }
                    }
                }
            }
        });
        parser.reset();
    }

    public TagHandler tagHandler(String tagName) {
        return this.tagHandlers.get(tagName);
    }

    static class BuilderImpl implements MarkwonHtmlRenderer.Builder {
        private boolean allowNonClosedTags;
        private final Map<String, TagHandler> tagHandlers = new HashMap(2);

        BuilderImpl() {
        }

        public MarkwonHtmlRenderer.Builder allowNonClosedTags(boolean allowNonClosedTags2) {
            this.allowNonClosedTags = allowNonClosedTags2;
            return this;
        }

        public MarkwonHtmlRenderer.Builder setHandler(String tagName, TagHandler tagHandler) {
            if (tagHandler == null) {
                this.tagHandlers.remove(tagName);
            } else {
                this.tagHandlers.put(tagName, tagHandler);
            }
            return this;
        }

        public MarkwonHtmlRenderer.Builder setHandler(Collection<String> tagNames, TagHandler tagHandler) {
            if (tagHandler == null) {
                for (String tagName : tagNames) {
                    this.tagHandlers.remove(tagName);
                }
            } else {
                for (String tagName2 : tagNames) {
                    this.tagHandlers.put(tagName2, tagHandler);
                }
            }
            return this;
        }

        public TagHandler getHandler(String tagName) {
            return this.tagHandlers.get(tagName);
        }

        public MarkwonHtmlRenderer build() {
            return this.tagHandlers.size() > 0 ? new MarkwonHtmlRendererImpl(this.allowNonClosedTags, Collections.unmodifiableMap(this.tagHandlers)) : new MarkwonHtmlRendererNoOp();
        }
    }
}
