package ru.noties.markwon.html.jsoup.nodes;

import java.util.Arrays;
import java.util.Iterator;
import ru.noties.markwon.html.jsoup.helper.Normalizer;
import ru.noties.markwon.html.jsoup.helper.Validate;

public class Attributes implements Iterable<Attribute>, Cloneable {
    private static final String[] Empty = new String[0];
    private static final String EmptyString = "";
    private static final int GrowthFactor = 2;
    private static final int InitialCapacity = 4;
    static final int NotFound = -1;
    String[] keys;
    /* access modifiers changed from: private */
    public int size = 0;
    String[] vals;

    public Attributes() {
        String[] strArr = Empty;
        this.keys = strArr;
        this.vals = strArr;
    }

    private void checkCapacity(int minNewSize) {
        Validate.isTrue(minNewSize >= this.size);
        String[] strArr = this.keys;
        int curSize = strArr.length;
        if (curSize < minNewSize) {
            int newSize = 4;
            if (curSize >= 4) {
                newSize = this.size * 2;
            }
            if (minNewSize > newSize) {
                newSize = minNewSize;
            }
            this.keys = copyOf(strArr, newSize);
            this.vals = copyOf(this.vals, newSize);
        }
    }

    private static String[] copyOf(String[] orig, int size2) {
        String[] copy = new String[size2];
        System.arraycopy(orig, 0, copy, 0, Math.min(orig.length, size2));
        return copy;
    }

    /* access modifiers changed from: package-private */
    public int indexOfKey(String key) {
        Validate.notNull(key);
        for (int i = 0; i < this.size; i++) {
            if (key.equals(this.keys[i])) {
                return i;
            }
        }
        return -1;
    }

    private int indexOfKeyIgnoreCase(String key) {
        Validate.notNull(key);
        for (int i = 0; i < this.size; i++) {
            if (key.equalsIgnoreCase(this.keys[i])) {
                return i;
            }
        }
        return -1;
    }

    static String checkNotNull(String val) {
        return val == null ? "" : val;
    }

    public String get(String key) {
        int i = indexOfKey(key);
        return i == -1 ? "" : checkNotNull(this.vals[i]);
    }

    public String getIgnoreCase(String key) {
        int i = indexOfKeyIgnoreCase(key);
        return i == -1 ? "" : checkNotNull(this.vals[i]);
    }

    private void add(String key, String value) {
        checkCapacity(this.size + 1);
        String[] strArr = this.keys;
        int i = this.size;
        strArr[i] = key;
        this.vals[i] = value;
        this.size = i + 1;
    }

    public Attributes put(String key, String value) {
        int i = indexOfKey(key);
        if (i != -1) {
            this.vals[i] = value;
        } else {
            add(key, value);
        }
        return this;
    }

    /* access modifiers changed from: package-private */
    public void putIgnoreCase(String key, String value) {
        int i = indexOfKeyIgnoreCase(key);
        if (i != -1) {
            this.vals[i] = value;
            if (!this.keys[i].equals(key)) {
                this.keys[i] = key;
                return;
            }
            return;
        }
        add(key, value);
    }

    public Attributes put(String key, boolean value) {
        if (value) {
            putIgnoreCase(key, (String) null);
        } else {
            remove(key);
        }
        return this;
    }

    public Attributes put(Attribute attribute) {
        Validate.notNull(attribute);
        put(attribute.getKey(), attribute.getValue());
        attribute.parent = this;
        return this;
    }

    /* access modifiers changed from: private */
    public void remove(int index) {
        Validate.isFalse(index >= this.size);
        int shifted = (this.size - index) - 1;
        if (shifted > 0) {
            String[] strArr = this.keys;
            System.arraycopy(strArr, index + 1, strArr, index, shifted);
            String[] strArr2 = this.vals;
            System.arraycopy(strArr2, index + 1, strArr2, index, shifted);
        }
        int i = this.size - 1;
        this.size = i;
        this.keys[i] = null;
        this.vals[i] = null;
    }

    public void remove(String key) {
        int i = indexOfKey(key);
        if (i != -1) {
            remove(i);
        }
    }

    public void removeIgnoreCase(String key) {
        int i = indexOfKeyIgnoreCase(key);
        if (i != -1) {
            remove(i);
        }
    }

    public boolean hasKey(String key) {
        return indexOfKey(key) != -1;
    }

    public boolean hasKeyIgnoreCase(String key) {
        return indexOfKeyIgnoreCase(key) != -1;
    }

    public int size() {
        return this.size;
    }

    public void addAll(Attributes incoming) {
        if (incoming.size() != 0) {
            checkCapacity(this.size + incoming.size);
            Iterator<Attribute> it = incoming.iterator();
            while (it.hasNext()) {
                put(it.next());
            }
        }
    }

    public Iterator<Attribute> iterator() {
        return new Iterator<Attribute>() {
            int i = 0;

            public boolean hasNext() {
                return this.i < Attributes.this.size;
            }

            public Attribute next() {
                String val = Attributes.this.vals[this.i];
                Attribute attr = new Attribute(Attributes.this.keys[this.i], val == null ? "" : val, Attributes.this);
                this.i++;
                return attr;
            }

            public void remove() {
                Attributes attributes = Attributes.this;
                int i2 = this.i - 1;
                this.i = i2;
                attributes.remove(i2);
            }
        };
    }

    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        Attributes that = (Attributes) o;
        if (this.size == that.size && Arrays.equals(this.keys, that.keys)) {
            return Arrays.equals(this.vals, that.vals);
        }
        return false;
    }

    public int hashCode() {
        return (((this.size * 31) + Arrays.hashCode(this.keys)) * 31) + Arrays.hashCode(this.vals);
    }

    public Attributes clone() {
        try {
            Attributes clone = (Attributes) super.clone();
            clone.size = this.size;
            this.keys = copyOf(this.keys, this.size);
            this.vals = copyOf(this.vals, this.size);
            return clone;
        } catch (CloneNotSupportedException e) {
            throw new RuntimeException(e);
        }
    }

    public void normalize() {
        for (int i = 0; i < this.size; i++) {
            String[] strArr = this.keys;
            strArr[i] = Normalizer.lowerCase(strArr[i]);
        }
    }
}
