package ru.noties.markwon.html.tag;

import android.text.TextUtils;
import java.util.Map;
import org.commonmark.node.Image;
import ru.noties.markwon.MarkwonConfiguration;
import ru.noties.markwon.RenderProps;
import ru.noties.markwon.SpanFactory;
import ru.noties.markwon.html.CssInlineStyleParser;
import ru.noties.markwon.html.HtmlTag;
import ru.noties.markwon.image.ImageProps;
import ru.noties.markwon.image.ImageSize;

public class ImageHandler extends SimpleTagHandler {
    private final ImageSizeParser imageSizeParser;

    interface ImageSizeParser {
        ImageSize parse(Map<String, String> map);
    }

    public static ImageHandler create() {
        return new ImageHandler(new ImageSizeParserImpl(CssInlineStyleParser.create()));
    }

    ImageHandler(ImageSizeParser imageSizeParser2) {
        this.imageSizeParser = imageSizeParser2;
    }

    public Object getSpans(MarkwonConfiguration configuration, RenderProps renderProps, HtmlTag tag) {
        SpanFactory spanFactory;
        String src = tag.attributes().get("src");
        if (TextUtils.isEmpty(src) || (spanFactory = configuration.spansFactory().get(Image.class)) == null) {
            return null;
        }
        String destination = configuration.urlProcessor().process(src);
        ImageSize imageSize = this.imageSizeParser.parse(tag.attributes());
        ImageProps.DESTINATION.set(renderProps, destination);
        ImageProps.IMAGE_SIZE.set(renderProps, imageSize);
        ImageProps.REPLACEMENT_TEXT_IS_LINK.set(renderProps, false);
        return spanFactory.getSpans(configuration, renderProps);
    }
}
