package ru.noties.markwon.html.tag;

import android.text.TextUtils;
import java.util.Map;
import ru.noties.markwon.html.CssInlineStyleParser;
import ru.noties.markwon.html.CssProperty;
import ru.noties.markwon.html.tag.ImageHandler;
import ru.noties.markwon.image.ImageSize;

class ImageSizeParserImpl implements ImageHandler.ImageSizeParser {
    private final CssInlineStyleParser inlineStyleParser;

    ImageSizeParserImpl(CssInlineStyleParser inlineStyleParser2) {
        this.inlineStyleParser = inlineStyleParser2;
    }

    public ImageSize parse(Map<String, String> attributes) {
        ImageSize.Dimension width = null;
        ImageSize.Dimension height = null;
        String style = attributes.get("style");
        if (!TextUtils.isEmpty(style)) {
            for (CssProperty cssProperty : this.inlineStyleParser.parse(style)) {
                String key = cssProperty.key();
                if ("width".equals(key)) {
                    width = dimension(cssProperty.value());
                } else if ("height".equals(key)) {
                    height = dimension(cssProperty.value());
                }
                if (width != null && height != null) {
                    break;
                }
            }
        }
        if (width != null && height != null) {
            return new ImageSize(width, height);
        }
        if (width == null) {
            width = dimension(attributes.get("width"));
        }
        if (height == null) {
            height = dimension(attributes.get("height"));
        }
        if (width == null && height == null) {
            return null;
        }
        return new ImageSize(width, height);
    }

    /* access modifiers changed from: package-private */
    public ImageSize.Dimension dimension(String value) {
        String unit;
        if (TextUtils.isEmpty(value)) {
            return null;
        }
        int length = value.length();
        int i = length - 1;
        while (i > -1) {
            if (Character.isDigit(value.charAt(i))) {
                try {
                    float val = Float.parseFloat(value.substring(0, i + 1));
                    if (i == length - 1) {
                        unit = null;
                    } else {
                        unit = value.substring(i + 1, length);
                    }
                    return new ImageSize.Dimension(val, unit);
                } catch (NumberFormatException e) {
                    return null;
                }
            } else {
                i--;
            }
        }
        return null;
    }
}
