package ru.noties.markwon.html.tag;

import android.text.style.StrikethroughSpan;
import org.commonmark.ext.gfm.strikethrough.Strikethrough;
import ru.noties.markwon.MarkwonConfiguration;
import ru.noties.markwon.MarkwonVisitor;
import ru.noties.markwon.SpanFactory;
import ru.noties.markwon.SpannableBuilder;
import ru.noties.markwon.html.HtmlTag;
import ru.noties.markwon.html.MarkwonHtmlRenderer;
import ru.noties.markwon.html.TagHandler;

public class StrikeHandler extends TagHandler {
    private static final boolean HAS_MARKDOWN_IMPLEMENTATION;

    static {
        boolean hasMarkdownImplementation;
        try {
            Strikethrough.class.getName();
            hasMarkdownImplementation = true;
        } catch (Throwable th) {
            hasMarkdownImplementation = false;
        }
        HAS_MARKDOWN_IMPLEMENTATION = hasMarkdownImplementation;
    }

    public void handle(MarkwonVisitor visitor, MarkwonHtmlRenderer renderer, HtmlTag tag) {
        if (tag.isBlock()) {
            visitChildren(visitor, renderer, tag.getAsBlock());
        }
        SpannableBuilder.setSpans(visitor.builder(), HAS_MARKDOWN_IMPLEMENTATION ? getMarkdownSpans(visitor) : new StrikethroughSpan(), tag.start(), tag.end());
    }

    private static Object getMarkdownSpans(MarkwonVisitor visitor) {
        MarkwonConfiguration configuration = visitor.configuration();
        SpanFactory spanFactory = configuration.spansFactory().get(Strikethrough.class);
        if (spanFactory == null) {
            return null;
        }
        return spanFactory.getSpans(configuration, visitor.renderProps());
    }
}
