package ru.noties.markwon.image;

import android.graphics.Canvas;
import android.graphics.ColorFilter;
import android.graphics.Rect;
import android.graphics.drawable.Animatable;
import android.graphics.drawable.Drawable;

public class AsyncDrawable extends Drawable {
    private Drawable.Callback callback;
    private int canvasWidth;
    private final String destination;
    private final ImageSize imageSize;
    private final ImageSizeResolver imageSizeResolver;
    private final AsyncDrawableLoader loader;
    private Drawable result;
    private float textSize;
    private boolean waitingForDimensions;

    public AsyncDrawable(String destination2, AsyncDrawableLoader loader2, ImageSizeResolver imageSizeResolver2, ImageSize imageSize2) {
        this.destination = destination2;
        this.loader = loader2;
        this.imageSizeResolver = imageSizeResolver2;
        this.imageSize = imageSize2;
        Drawable placeholder = loader2.placeholder();
        if (placeholder != null) {
            if (placeholder.getBounds().isEmpty()) {
                Rect rect = new Rect(0, 0, placeholder.getIntrinsicWidth(), placeholder.getIntrinsicHeight());
                placeholder.setBounds(rect);
                setBounds(rect);
            }
            setResult(placeholder);
        }
    }

    public String getDestination() {
        return this.destination;
    }

    public Drawable getResult() {
        return this.result;
    }

    public boolean hasResult() {
        return this.result != null;
    }

    public boolean isAttached() {
        return getCallback() != null;
    }

    public void setCallback2(Drawable.Callback callback2) {
        this.callback = callback2;
        super.setCallback(callback2);
        if (callback2 != null) {
            Drawable drawable = this.result;
            if (drawable != null && drawable.getCallback() == null) {
                this.result.setCallback(callback2);
            }
            this.loader.load(this.destination, this);
            return;
        }
        Drawable drawable2 = this.result;
        if (drawable2 != null) {
            drawable2.setCallback((Drawable.Callback) null);
            Drawable drawable3 = this.result;
            if (drawable3 instanceof Animatable) {
                ((Animatable) drawable3).stop();
            }
        }
        this.loader.cancel(this.destination);
    }

    public void setResult(Drawable result2) {
        Drawable drawable = this.result;
        if (drawable != null) {
            drawable.setCallback((Drawable.Callback) null);
        }
        this.result = result2;
        result2.setCallback(this.callback);
        initBounds();
    }

    private void initBounds() {
        if (this.canvasWidth == 0) {
            this.waitingForDimensions = true;
            return;
        }
        this.waitingForDimensions = false;
        Rect bounds = resolveBounds();
        this.result.setBounds(bounds);
        setBounds(bounds);
        invalidateSelf();
    }

    public void initWithKnownDimensions(int width, float textSize2) {
        this.canvasWidth = width;
        this.textSize = textSize2;
        if (this.waitingForDimensions) {
            initBounds();
        }
    }

    public void draw(Canvas canvas) {
        if (hasResult()) {
            this.result.draw(canvas);
        }
    }

    public void setAlpha(int alpha) {
    }

    public void setColorFilter(ColorFilter colorFilter) {
    }

    public int getOpacity() {
        if (hasResult()) {
            return this.result.getOpacity();
        }
        return -2;
    }

    public int getIntrinsicWidth() {
        if (hasResult()) {
            return this.result.getIntrinsicWidth();
        }
        return 0;
    }

    public int getIntrinsicHeight() {
        if (hasResult()) {
            return this.result.getIntrinsicHeight();
        }
        return 0;
    }

    private Rect resolveBounds() {
        ImageSizeResolver imageSizeResolver2 = this.imageSizeResolver;
        if (imageSizeResolver2 != null) {
            return imageSizeResolver2.resolveImageSize(this.imageSize, this.result.getBounds(), this.canvasWidth, this.textSize);
        }
        return this.result.getBounds();
    }
}
