package ru.noties.markwon.image;

import android.graphics.drawable.Drawable;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public abstract class AsyncDrawableLoader {

    public interface DrawableProvider {
        Drawable provide();
    }

    public abstract void cancel(String str);

    public abstract void load(String str, AsyncDrawable asyncDrawable);

    public abstract Drawable placeholder();

    public static Builder builder() {
        return new Builder();
    }

    public static AsyncDrawableLoader noOp() {
        return new AsyncDrawableLoaderNoOp();
    }

    public static class Builder {
        MediaDecoder defaultMediaDecoder;
        DrawableProvider errorDrawableProvider;
        ExecutorService executorService;
        final Map<String, MediaDecoder> mediaDecoders = new HashMap(3);
        DrawableProvider placeholderDrawableProvider;
        final Map<String, SchemeHandler> schemeHandlers = new HashMap(3);

        public Builder executorService(ExecutorService executorService2) {
            this.executorService = executorService2;
            return this;
        }

        public Builder addSchemeHandler(String scheme, SchemeHandler schemeHandler) {
            this.schemeHandlers.put(scheme, schemeHandler);
            return this;
        }

        public Builder addSchemeHandler(Collection<String> schemes, SchemeHandler schemeHandler) {
            for (String scheme : schemes) {
                this.schemeHandlers.put(scheme, schemeHandler);
            }
            return this;
        }

        public Builder addMediaDecoder(String contentType, MediaDecoder mediaDecoder) {
            this.mediaDecoders.put(contentType, mediaDecoder);
            return this;
        }

        public Builder addMediaDecoder(Collection<String> contentTypes, MediaDecoder mediaDecoder) {
            for (String contentType : contentTypes) {
                this.mediaDecoders.put(contentType, mediaDecoder);
            }
            return this;
        }

        public Builder removeSchemeHandler(String scheme) {
            this.schemeHandlers.remove(scheme);
            return this;
        }

        public Builder removeMediaDecoder(String contentType) {
            this.mediaDecoders.remove(contentType);
            return this;
        }

        public Builder defaultMediaDecoder(MediaDecoder mediaDecoder) {
            this.defaultMediaDecoder = mediaDecoder;
            return this;
        }

        public Builder placeholderDrawableProvider(DrawableProvider placeholderDrawableProvider2) {
            this.placeholderDrawableProvider = placeholderDrawableProvider2;
            return this;
        }

        public Builder errorDrawableProvider(DrawableProvider errorDrawableProvider2) {
            this.errorDrawableProvider = errorDrawableProvider2;
            return this;
        }

        public AsyncDrawableLoader build() {
            if (this.schemeHandlers.size() == 0 || (this.mediaDecoders.size() == 0 && this.defaultMediaDecoder == null)) {
                return new AsyncDrawableLoaderNoOp();
            }
            if (this.executorService == null) {
                this.executorService = Executors.newCachedThreadPool();
            }
            return new AsyncDrawableLoaderImpl(this);
        }
    }
}
