package ru.noties.markwon.image;

import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.os.Handler;
import android.os.Looper;
import java.io.IOException;
import java.io.InputStream;
import java.lang.ref.WeakReference;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Future;
import ru.noties.markwon.image.AsyncDrawableLoader;

class AsyncDrawableLoaderImpl extends AsyncDrawableLoader {
    /* access modifiers changed from: private */
    public final MediaDecoder defaultMediaDecoder;
    /* access modifiers changed from: private */
    public final AsyncDrawableLoader.DrawableProvider errorDrawableProvider;
    private final ExecutorService executorService;
    /* access modifiers changed from: private */
    public final Handler mainThread;
    /* access modifiers changed from: private */
    public final Map<String, MediaDecoder> mediaDecoders;
    private final AsyncDrawableLoader.DrawableProvider placeholderDrawableProvider;
    /* access modifiers changed from: private */
    public final Map<String, Future<?>> requests = new HashMap(2);
    /* access modifiers changed from: private */
    public final Map<String, SchemeHandler> schemeHandlers;

    AsyncDrawableLoaderImpl(AsyncDrawableLoader.Builder builder) {
        this.executorService = builder.executorService;
        this.schemeHandlers = builder.schemeHandlers;
        this.mediaDecoders = builder.mediaDecoders;
        this.defaultMediaDecoder = builder.defaultMediaDecoder;
        this.placeholderDrawableProvider = builder.placeholderDrawableProvider;
        this.errorDrawableProvider = builder.errorDrawableProvider;
        this.mainThread = new Handler(Looper.getMainLooper());
    }

    public void load(String destination, AsyncDrawable drawable) {
        this.requests.put(destination, execute(destination, drawable));
    }

    public void cancel(String destination) {
        Future<?> request = this.requests.remove(destination);
        if (request != null) {
            request.cancel(true);
        }
    }

    public Drawable placeholder() {
        AsyncDrawableLoader.DrawableProvider drawableProvider = this.placeholderDrawableProvider;
        if (drawableProvider != null) {
            return drawableProvider.provide();
        }
        return null;
    }

    private Future<?> execute(final String destination, AsyncDrawable drawable) {
        final WeakReference<AsyncDrawable> reference = new WeakReference<>(drawable);
        return this.executorService.submit(new Runnable() {
            public void run() {
                ImageItem item;
                Uri uri = Uri.parse(destination);
                SchemeHandler schemeHandler = (SchemeHandler) AsyncDrawableLoaderImpl.this.schemeHandlers.get(uri.getScheme());
                if (schemeHandler != null) {
                    item = schemeHandler.handle(destination, uri);
                } else {
                    item = null;
                }
                Drawable drawable = null;
                InputStream inputStream = item != null ? item.inputStream() : null;
                Drawable result = null;
                if (inputStream != null) {
                    try {
                        MediaDecoder mediaDecoder = (MediaDecoder) AsyncDrawableLoaderImpl.this.mediaDecoders.get(item.contentType());
                        if (mediaDecoder == null) {
                            mediaDecoder = AsyncDrawableLoaderImpl.this.defaultMediaDecoder;
                        }
                        if (mediaDecoder != null) {
                            result = mediaDecoder.decode(inputStream);
                        }
                    } finally {
                        try {
                            inputStream.close();
                        } catch (IOException e) {
                        }
                    }
                }
                if (result == null) {
                    if (AsyncDrawableLoaderImpl.this.errorDrawableProvider != null) {
                        drawable = AsyncDrawableLoaderImpl.this.errorDrawableProvider.provide();
                    }
                    result = drawable;
                }
                if (result != null) {
                    final Drawable out = result;
                    AsyncDrawableLoaderImpl.this.mainThread.post(new Runnable() {
                        public void run() {
                            AsyncDrawable asyncDrawable;
                            if ((AsyncDrawableLoaderImpl.this.requests.remove(destination) != null) && (asyncDrawable = (AsyncDrawable) reference.get()) != null && asyncDrawable.isAttached()) {
                                asyncDrawable.setResult(out);
                            }
                        }
                    });
                    return;
                }
                AsyncDrawableLoaderImpl.this.requests.remove(destination);
            }
        });
    }
}
