package ru.noties.markwon.image;

import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.os.Looper;
import android.os.SystemClock;
import android.text.Spanned;
import android.text.style.DynamicDrawableSpan;
import android.view.View;
import android.widget.TextView;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import ru.noties.markwon.renderer.R;

public abstract class AsyncDrawableScheduler {
    public static void schedule(final TextView textView) {
        List<AsyncDrawable> list = extract(textView);
        if (list.size() > 0) {
            if (textView.getTag(R.id.markwon_drawables_scheduler) == null) {
                View.OnAttachStateChangeListener listener = new View.OnAttachStateChangeListener() {
                    public void onViewAttachedToWindow(View v) {
                    }

                    public void onViewDetachedFromWindow(View v) {
                        AsyncDrawableScheduler.unschedule(textView);
                        v.removeOnAttachStateChangeListener(this);
                        v.setTag(R.id.markwon_drawables_scheduler, (Object) null);
                    }
                };
                textView.addOnAttachStateChangeListener(listener);
                textView.setTag(R.id.markwon_drawables_scheduler, listener);
            }
            for (AsyncDrawable drawable : list) {
                drawable.setCallback2(new DrawableCallbackImpl(textView, drawable.getBounds()));
            }
        }
    }

    public static void unschedule(TextView view) {
        for (AsyncDrawable drawable : extract(view)) {
            drawable.setCallback2((Drawable.Callback) null);
        }
    }

    private static List<AsyncDrawable> extract(TextView view) {
        CharSequence cs = view.getText();
        int length = cs != null ? cs.length() : 0;
        if (length == 0 || !(cs instanceof Spanned)) {
            return Collections.EMPTY_LIST;
        }
        List<AsyncDrawable> drawables = new ArrayList<>(2);
        Spanned spanned = (Spanned) cs;
        AsyncDrawableSpan[] asyncDrawableSpans = (AsyncDrawableSpan[]) spanned.getSpans(0, length, AsyncDrawableSpan.class);
        if (asyncDrawableSpans != null && asyncDrawableSpans.length > 0) {
            for (AsyncDrawableSpan span : asyncDrawableSpans) {
                drawables.add(span.getDrawable());
            }
        }
        DynamicDrawableSpan[] dynamicDrawableSpans = (DynamicDrawableSpan[]) spanned.getSpans(0, length, DynamicDrawableSpan.class);
        if (dynamicDrawableSpans != null && dynamicDrawableSpans.length > 0) {
            for (DynamicDrawableSpan span2 : dynamicDrawableSpans) {
                Drawable d = span2.getDrawable();
                if (d != null && (d instanceof AsyncDrawable)) {
                    drawables.add((AsyncDrawable) d);
                }
            }
        }
        if (drawables.size() == 0) {
            return Collections.EMPTY_LIST;
        }
        return drawables;
    }

    private AsyncDrawableScheduler() {
    }

    private static class DrawableCallbackImpl implements Drawable.Callback {
        private Rect previousBounds;
        private final TextView view;

        DrawableCallbackImpl(TextView view2, Rect initialBounds) {
            this.view = view2;
            this.previousBounds = new Rect(initialBounds);
        }

        public void invalidateDrawable(final Drawable who) {
            if (Looper.myLooper() != Looper.getMainLooper()) {
                this.view.post(new Runnable() {
                    public void run() {
                        DrawableCallbackImpl.this.invalidateDrawable(who);
                    }
                });
                return;
            }
            Rect rect = who.getBounds();
            if (!this.previousBounds.equals(rect)) {
                TextView textView = this.view;
                textView.setText(textView.getText());
                this.previousBounds = new Rect(rect);
                return;
            }
            this.view.postInvalidate();
        }

        public void scheduleDrawable(Drawable who, Runnable what, long when) {
            this.view.postDelayed(what, when - SystemClock.uptimeMillis());
        }

        public void unscheduleDrawable(Drawable who, Runnable what) {
            this.view.removeCallbacks(what);
        }
    }
}
