package ru.noties.markwon.image;

import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.text.style.ReplacementSpan;
import ru.noties.markwon.core.MarkwonTheme;

public class AsyncDrawableSpan extends ReplacementSpan {
    public static final int ALIGN_BASELINE = 1;
    public static final int ALIGN_BOTTOM = 0;
    public static final int ALIGN_CENTER = 2;
    private final int alignment;
    private final AsyncDrawable drawable;
    private final boolean replacementTextIsLink;
    private final MarkwonTheme theme;

    public AsyncDrawableSpan(MarkwonTheme theme2, AsyncDrawable drawable2, int alignment2, boolean replacementTextIsLink2) {
        this.theme = theme2;
        this.drawable = drawable2;
        this.alignment = alignment2;
        this.replacementTextIsLink = replacementTextIsLink2;
        if (drawable2.getBounds().isEmpty()) {
            drawable2.setBounds(0, 0, drawable2.getIntrinsicWidth(), drawable2.getIntrinsicHeight());
        }
    }

    public int getSize(Paint paint, CharSequence text, int start, int end, Paint.FontMetricsInt fm) {
        if (this.drawable.hasResult()) {
            Rect rect = this.drawable.getBounds();
            if (fm != null) {
                fm.ascent = -rect.bottom;
                fm.descent = 0;
                fm.top = fm.ascent;
                fm.bottom = 0;
            }
            return rect.right;
        }
        if (this.replacementTextIsLink != 0) {
            this.theme.applyLinkStyle(paint);
        }
        return (int) (paint.measureText(text, start, end) + 0.5f);
    }

    public void draw(Canvas canvas, CharSequence text, int start, int end, float x, int top, int y, int bottom, Paint paint) {
        int translationY;
        Canvas canvas2 = canvas;
        int i = top;
        int i2 = bottom;
        Paint paint2 = paint;
        this.drawable.initWithKnownDimensions(canvas.getWidth(), paint.getTextSize());
        AsyncDrawable drawable2 = this.drawable;
        if (drawable2.hasResult()) {
            int b = i2 - drawable2.getBounds().bottom;
            int save = canvas.save();
            try {
                int i3 = this.alignment;
                if (2 == i3) {
                    translationY = b - (((i2 - i) - drawable2.getBounds().height()) / 2);
                } else if (1 == i3) {
                    translationY = b - paint.getFontMetricsInt().descent;
                } else {
                    translationY = b;
                }
                try {
                    canvas2.translate(x, (float) translationY);
                    drawable2.draw(canvas2);
                    canvas2.restoreToCount(save);
                } catch (Throwable th) {
                    th = th;
                    canvas2.restoreToCount(save);
                    throw th;
                }
            } catch (Throwable th2) {
                th = th2;
                float f = x;
                canvas2.restoreToCount(save);
                throw th;
            }
        } else {
            float f2 = x;
            float textY = textCenterY(i, i2, paint2);
            if (this.replacementTextIsLink) {
                this.theme.applyLinkStyle(paint2);
            }
            canvas.drawText(text, start, end, x, textY, paint);
        }
    }

    public AsyncDrawable getDrawable() {
        return this.drawable;
    }

    private static float textCenterY(int top, int bottom, Paint paint) {
        return (float) ((int) (((float) (((bottom - top) / 2) + top)) - (((paint.descent() + paint.ascent()) / 2.0f) + 0.5f)));
    }
}
