package ru.noties.markwon.image;

import android.content.Context;
import android.text.Spanned;
import android.widget.TextView;
import java.util.Arrays;
import java.util.Collection;
import org.commonmark.node.Image;
import org.commonmark.node.Link;
import ru.noties.markwon.AbstractMarkwonPlugin;
import ru.noties.markwon.MarkwonConfiguration;
import ru.noties.markwon.MarkwonSpansFactory;
import ru.noties.markwon.MarkwonVisitor;
import ru.noties.markwon.RenderProps;
import ru.noties.markwon.SpanFactory;
import ru.noties.markwon.image.AsyncDrawableLoader;
import ru.noties.markwon.image.data.DataUriSchemeHandler;
import ru.noties.markwon.image.file.FileSchemeHandler;
import ru.noties.markwon.image.network.NetworkSchemeHandler;

public class ImagesPlugin extends AbstractMarkwonPlugin {
    private final Context context;
    private final boolean useAssets;

    public static ImagesPlugin create(Context context2) {
        return new ImagesPlugin(context2, false);
    }

    public static ImagesPlugin createWithAssets(Context context2) {
        return new ImagesPlugin(context2, true);
    }

    protected ImagesPlugin(Context context2, boolean useAssets2) {
        this.context = context2;
        this.useAssets = useAssets2;
    }

    public void configureImages(AsyncDrawableLoader.Builder builder) {
        FileSchemeHandler fileSchemeHandler;
        if (this.useAssets) {
            fileSchemeHandler = FileSchemeHandler.createWithAssets(this.context.getAssets());
        } else {
            fileSchemeHandler = FileSchemeHandler.create();
        }
        builder.addSchemeHandler("data", (SchemeHandler) DataUriSchemeHandler.create()).addSchemeHandler(FileSchemeHandler.SCHEME, (SchemeHandler) fileSchemeHandler).addSchemeHandler((Collection<String>) Arrays.asList(new String[]{NetworkSchemeHandler.SCHEME_HTTP, NetworkSchemeHandler.SCHEME_HTTPS}), (SchemeHandler) NetworkSchemeHandler.create()).defaultMediaDecoder(ImageMediaDecoder.create(this.context.getResources()));
    }

    public void configureSpansFactory(MarkwonSpansFactory.Builder builder) {
        builder.setFactory(Image.class, new ImageSpanFactory());
    }

    public void configureVisitor(MarkwonVisitor.Builder builder) {
        builder.on(Image.class, new MarkwonVisitor.NodeVisitor<Image>() {
            public void visit(MarkwonVisitor visitor, Image image) {
                SpanFactory spanFactory = visitor.configuration().spansFactory().get(Image.class);
                if (spanFactory == null) {
                    visitor.visitChildren(image);
                    return;
                }
                int length = visitor.length();
                visitor.visitChildren(image);
                if (length == visitor.length()) {
                    visitor.builder().append(65532);
                }
                MarkwonConfiguration configuration = visitor.configuration();
                String destination = configuration.urlProcessor().process(image.getDestination());
                RenderProps props = visitor.renderProps();
                ImageProps.DESTINATION.set(props, destination);
                ImageProps.REPLACEMENT_TEXT_IS_LINK.set(props, Boolean.valueOf(image.getParent() instanceof Link));
                ImageProps.IMAGE_SIZE.set(props, null);
                visitor.setSpans(length, spanFactory.getSpans(configuration, props));
            }
        });
    }

    public void beforeSetText(TextView textView, Spanned markdown) {
        AsyncDrawableScheduler.unschedule(textView);
    }

    public void afterSetText(TextView textView) {
        AsyncDrawableScheduler.schedule(textView);
    }
}
