package ru.noties.markwon.image.data;

import android.net.Uri;
import java.io.ByteArrayInputStream;
import ru.noties.markwon.image.ImageItem;
import ru.noties.markwon.image.SchemeHandler;

public class DataUriSchemeHandler extends SchemeHandler {
    public static final String SCHEME = "data";
    private static final String START = "data:";
    private final DataUriDecoder uriDecoder;
    private final DataUriParser uriParser;

    public static DataUriSchemeHandler create() {
        return new DataUriSchemeHandler(DataUriParser.create(), DataUriDecoder.create());
    }

    DataUriSchemeHandler(DataUriParser uriParser2, DataUriDecoder uriDecoder2) {
        this.uriParser = uriParser2;
        this.uriDecoder = uriDecoder2;
    }

    public ImageItem handle(String raw, Uri uri) {
        byte[] bytes;
        if (!raw.startsWith(START)) {
            return null;
        }
        String part = raw.substring(START.length());
        if (part.startsWith("//")) {
            part = part.substring(2);
        }
        DataUri dataUri = this.uriParser.parse(part);
        if (dataUri == null || (bytes = this.uriDecoder.decode(dataUri)) == null) {
            return null;
        }
        return new ImageItem(dataUri.contentType(), new ByteArrayInputStream(bytes));
    }
}
