package ru.noties.markwon.image.file;

import android.content.res.AssetManager;
import android.net.Uri;
import android.webkit.MimeTypeMap;
import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.List;
import ru.noties.markwon.image.ImageItem;
import ru.noties.markwon.image.SchemeHandler;

public class FileSchemeHandler extends SchemeHandler {
    private static final String FILE_ANDROID_ASSETS = "android_asset";
    public static final String SCHEME = "file";
    private final AssetManager assetManager;

    public static FileSchemeHandler createWithAssets(AssetManager assetManager2) {
        return new FileSchemeHandler(assetManager2);
    }

    public static FileSchemeHandler create() {
        return new FileSchemeHandler((AssetManager) null);
    }

    FileSchemeHandler(AssetManager assetManager2) {
        this.assetManager = assetManager2;
    }

    public ImageItem handle(String raw, Uri uri) {
        List<String> segments = uri.getPathSegments();
        if (segments == null || segments.size() == 0) {
            return null;
        }
        InputStream inputStream = null;
        boolean assets = FILE_ANDROID_ASSETS.equals(segments.get(0));
        String fileName = uri.getLastPathSegment();
        if (!assets) {
            try {
                inputStream = new BufferedInputStream(new FileInputStream(new File(uri.getPath())));
            } catch (FileNotFoundException e) {
                e.printStackTrace();
            }
        } else if (this.assetManager != null) {
            StringBuilder path = new StringBuilder();
            int size = segments.size();
            for (int i = 1; i < size; i++) {
                if (i != 1) {
                    path.append('/');
                }
                path.append(segments.get(i));
            }
            try {
                inputStream = this.assetManager.open(path.toString());
            } catch (IOException e2) {
                e2.printStackTrace();
            }
        }
        if (inputStream != null) {
            return new ImageItem(MimeTypeMap.getSingleton().getMimeTypeFromExtension(MimeTypeMap.getFileExtensionFromUrl(fileName)), inputStream);
        }
        return null;
    }
}
