package ru.noties.markwon.priority;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import ru.noties.markwon.MarkwonPlugin;

public abstract class Priority {

    public interface Builder {
        Builder after(Class<? extends MarkwonPlugin> cls);

        Priority build();
    }

    public abstract List<Class<? extends MarkwonPlugin>> after();

    public static Priority none() {
        return builder().build();
    }

    public static Priority after(Class<? extends MarkwonPlugin> plugin) {
        return builder().after(plugin).build();
    }

    public static Priority after(Class<? extends MarkwonPlugin> plugin1, Class<? extends MarkwonPlugin> plugin2) {
        return builder().after(plugin1).after(plugin2).build();
    }

    public static Builder builder() {
        return new Impl.BuilderImpl();
    }

    static class Impl extends Priority {
        private final List<Class<? extends MarkwonPlugin>> after;

        Impl(List<Class<? extends MarkwonPlugin>> after2) {
            this.after = after2;
        }

        public List<Class<? extends MarkwonPlugin>> after() {
            return this.after;
        }

        public String toString() {
            return "Priority{after=" + this.after + '}';
        }

        static class BuilderImpl implements Builder {
            private final List<Class<? extends MarkwonPlugin>> after = new ArrayList(0);

            BuilderImpl() {
            }

            public Builder after(Class<? extends MarkwonPlugin> plugin) {
                this.after.add(plugin);
                return this;
            }

            public Priority build() {
                return new Impl(Collections.unmodifiableList(this.after));
            }
        }
    }
}
