package ru.noties.markwon.utils;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;
import org.commonmark.node.Block;
import org.commonmark.node.Node;
import org.commonmark.node.Visitor;

public abstract class DumpNodes {

    public interface NodeProcessor {
        String process(Node node);
    }

    public static String dump(Node node) {
        return dump(node, (NodeProcessor) null);
    }

    public static String dump(Node node, NodeProcessor nodeProcessor) {
        final NodeProcessor processor = nodeProcessor != null ? nodeProcessor : new NodeProcessorToString();
        final Indent indent = new Indent();
        final StringBuilder builder = new StringBuilder();
        node.accept((Visitor) Proxy.newProxyInstance(Visitor.class.getClassLoader(), new Class[]{Visitor.class}, new InvocationHandler() {
            public Object invoke(Object proxy, Method method, Object[] args) {
                Node argument = args[0];
                indent.appendTo(builder);
                builder.append(processor.process(argument));
                if (argument instanceof Block) {
                    builder.append(" [\n");
                    indent.increment();
                    DumpNodes.visitChildren((Visitor) proxy, argument);
                    indent.decrement();
                    indent.appendTo(builder);
                    builder.append("]\n");
                    return null;
                }
                builder.append(10);
                return null;
            }
        }));
        return builder.toString();
    }

    private DumpNodes() {
    }

    private static class Indent {
        private int count;

        private Indent() {
        }

        /* access modifiers changed from: package-private */
        public void increment() {
            this.count++;
        }

        /* access modifiers changed from: package-private */
        public void decrement() {
            this.count--;
        }

        /* access modifiers changed from: package-private */
        public void appendTo(StringBuilder builder) {
            for (int i = 0; i < this.count; i++) {
                builder.append(' ');
                builder.append(' ');
            }
        }
    }

    /* access modifiers changed from: private */
    public static void visitChildren(Visitor visitor, Node parent) {
        Node node = parent.getFirstChild();
        while (node != null) {
            Node next = node.getNext();
            node.accept(visitor);
            node = next;
        }
    }

    private static class NodeProcessorToString implements NodeProcessor {
        private NodeProcessorToString() {
        }

        public String process(Node node) {
            return node.toString();
        }
    }
}
